pub enum AuthScheme {
    None,
    AccessToken,
    ServerSignatures,
}
Available on crate feature api only.
Authentication scheme used by the endpoint.

Variants



None

No authentication is performed.



AccessToken

Authentication is performed by including an access token in the Authentication http header, or an access_token query parameter.

It is recommended to use the header over the query parameter.



ServerSignatures

Authentication is performed by including X-Matrix signatures in the request headers, as defined in the federation API.