OutgoingResponse

Trait OutgoingResponse 

pub trait OutgoingResponse {
    // Required method
    fn try_into_http_response<T: Default + BufMut>(
        self,
    ) -> Result<Response<T>, IntoHttpError>;
}
Available on crate feature api only.
A request type for a Matrix API endpoint, used for sending responses.

Required Methods

fn try_into_http_response<T: Default + BufMut>( self, ) -> Result<Response<T>, IntoHttpError>

Tries to convert this response into an http::Response.

This method should only fail when when invalid header values are specified. It may also fail with a serialization error in case of bugs in Ruma though.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors