pub enum RedactionError {
NotOfType {
field: String,
of_type: JsonType,
},
JsonFieldMissingFromObject(String),
}Available on crate feature
canonical-json only.Expand description
Errors that can happen in redaction.
Variants
NotOfType
The field field is not of the correct type of_type (JsonType).
JsonFieldMissingFromObject(String)
The given required field is missing from a JSON object.