pub struct Filter<'a> {
pub generic_search_term: Option<&'a str>,
}Expand description
A filter for public rooms lists
A string to search for in the room metadata, e.g. name, topic, canonical alias etc.
Returns true if the filter is empty.
Performs copy-assignment from source. Read more
Formats the value using the given formatter. Read more
Returns the “default value” for a type. Read more
The ‘Incoming’ variant of Self.
Serialize this value into the given Serde serializer. Read more
impl<T> Any for T where
T: 'static + ?Sized,
Immutably borrows from an owned value. Read more
Mutably borrows from an owned value. Read more
Instruments this type with the provided Span, returning an
Instrumented wrapper. Read more
Instruments this type with the current Span, returning an
Instrumented wrapper. Read more
impl<T, U> Into<U> for T where
U: From<T>,
The resulting type after obtaining ownership.
Creates owned data from borrowed data, usually by cloning. Read more
🔬 This is a nightly-only experimental API. (toowned_clone_into)
recently added
Uses borrowed data to replace owned data, usually by cloning. Read more
The type returned in the event of a conversion error.
The type returned in the event of a conversion error.