Struct ruma_common::encryption::DeviceKeys
source · pub struct DeviceKeys {
pub user_id: OwnedUserId,
pub device_id: OwnedDeviceId,
pub algorithms: Vec<EventEncryptionAlgorithm>,
pub keys: BTreeMap<OwnedDeviceKeyId, String>,
pub signatures: BTreeMap<OwnedUserId, BTreeMap<OwnedDeviceKeyId, String>>,
pub unsigned: UnsignedDeviceInfo,
}Expand description
Identity keys for a device.
Fields
user_id: OwnedUserIdThe ID of the user the device belongs to.
Must match the user ID used when logging in.
device_id: OwnedDeviceIdThe ID of the device these keys belong to.
Must match the device ID used when logging in.
algorithms: Vec<EventEncryptionAlgorithm>The encryption algorithms supported by this device.
keys: BTreeMap<OwnedDeviceKeyId, String>Public identity keys.
signatures: BTreeMap<OwnedUserId, BTreeMap<OwnedDeviceKeyId, String>>Signatures for the device key object.
unsigned: UnsignedDeviceInfoAdditional data added to the device key information by intermediate servers, and not covered by the signatures.
Implementations
sourceimpl DeviceKeys
impl DeviceKeys
sourcepub fn new(
user_id: OwnedUserId,
device_id: OwnedDeviceId,
algorithms: Vec<EventEncryptionAlgorithm>,
keys: BTreeMap<OwnedDeviceKeyId, String>,
signatures: BTreeMap<OwnedUserId, BTreeMap<OwnedDeviceKeyId, String>>
) -> Self
pub fn new(
user_id: OwnedUserId,
device_id: OwnedDeviceId,
algorithms: Vec<EventEncryptionAlgorithm>,
keys: BTreeMap<OwnedDeviceKeyId, String>,
signatures: BTreeMap<OwnedUserId, BTreeMap<OwnedDeviceKeyId, String>>
) -> Self
Creates a new DeviceKeys from the given user id, device id, algorithms, keys and
signatures.