Struct ruma_common::encryption::UnsignedDeviceInfo [−][src]
Additional data added to device key information by intermediate servers.
Fields
device_display_name: Option<String>The display name which the user set on the device.
Implementations