Struct ruma_common::events::audio::AudioEventContent
source · [−]pub struct AudioEventContent {
pub message: MessageContent,
pub file: FileContent,
pub audio: AudioContent,
pub relates_to: Option<Relation>,
}events and unstable-msc3246 only.Expand description
The payload for an extensible audio message.
This is the new primary type introduced in MSC3246 and should not be sent before the end of
the transition period. See the documentation of the message module for more information.
AudioEventContent can be converted to a RoomMessageEventContent with a
MessageType::Audio. You can convert it back with
AudioEventContent::from_audio_room_message().
Fields
message: MessageContentThe text representation of the message.
file: FileContentThe file content of the message.
audio: AudioContentThe audio content of the message.
relates_to: Option<Relation>Information about related messages.
Implementations
sourceimpl AudioEventContent
impl AudioEventContent
sourcepub fn plain(message: impl Into<String>, file: FileContent) -> Self
pub fn plain(message: impl Into<String>, file: FileContent) -> Self
Creates a new AudioEventContent with the given plain text message and file.
sourcepub fn with_message(message: MessageContent, file: FileContent) -> Self
pub fn with_message(message: MessageContent, file: FileContent) -> Self
Creates a new AudioEventContent with the given message and file.
sourcepub fn from_audio_room_message(
content: AudioMessageEventContent,
relates_to: Option<Relation>
) -> Self
pub fn from_audio_room_message(
content: AudioMessageEventContent,
relates_to: Option<Relation>
) -> Self
Create a new AudioEventContent from the given AudioMessageEventContent and optional
relation.