pub struct Waveform(_);
Available on crate features events and unstable-msc3246 only.
The waveform representation of audio content.

Must include between 30 and 120 Amplitudes.

To build this, use the TryFrom implementations.

Implementations

source

impl Waveform

source

pub const MIN_LENGTH: usize = 30usize

The smallest number of values contained in a Waveform.

source

pub const MAX_LENGTH: usize = 120usize

The largest number of values contained in a Waveform.

source

pub fn amplitudes(&self) -> &[Amplitude]

The amplitudes of this Waveform.