Struct ruma_common::events::call::answer::CallAnswerEventContent
source · pub struct CallAnswerEventContent {
pub answer: AnswerSessionDescription,
pub call_id: OwnedVoipId,
pub party_id: Option<OwnedVoipId>,
pub version: VoipVersionId,
pub capabilities: CallCapabilities,
}Available on crate feature
events only.Expand description
The content of an m.call.answer event.
This event is sent by the callee when they wish to answer the call.
Fields
answer: AnswerSessionDescriptionThe VoIP session description object.
call_id: OwnedVoipIdA unique identifier for the call.
party_id: Option<OwnedVoipId>Available on crate feature
unstable-msc2746 only.Required in VoIP version 1. A unique ID for this session for the duration of the call.
version: VoipVersionIdThe version of the VoIP specification this messages adheres to.
capabilities: CallCapabilitiesAvailable on crate feature
unstable-msc2746 only.Added in VoIP version 1. The VoIP capabilities of the client.
Implementations
sourceimpl CallAnswerEventContent
impl CallAnswerEventContent
sourcepub fn new(
answer: AnswerSessionDescription,
call_id: OwnedVoipId,
version: VoipVersionId
) -> Self
pub fn new(
answer: AnswerSessionDescription,
call_id: OwnedVoipId,
version: VoipVersionId
) -> Self
Creates an CallAnswerEventContent with the given answer, call ID and VoIP version.
sourcepub fn version_0(answer: AnswerSessionDescription, call_id: OwnedVoipId) -> Self
pub fn version_0(answer: AnswerSessionDescription, call_id: OwnedVoipId) -> Self
Convenience method to create a VoIP version 0 CallAnswerEventContent with all the required
fields.
sourcepub fn version_1(
answer: AnswerSessionDescription,
call_id: OwnedVoipId,
party_id: OwnedVoipId,
capabilities: CallCapabilities
) -> Self
Available on crate feature unstable-msc2746 only.
pub fn version_1(
answer: AnswerSessionDescription,
call_id: OwnedVoipId,
party_id: OwnedVoipId,
capabilities: CallCapabilities
) -> Self
unstable-msc2746 only.Convenience method to create a VoIP version 1 CallAnswerEventContent with all the required
fields.