Enum ruma_common::events::call::SessionDescriptionType
source · #[non_exhaustive]
pub enum SessionDescriptionType {
Answer,
Offer,
PrAnswer,
Rollback,
// some variants omitted
}Available on crate feature
events only.Expand description
The type of VoIP session description.
This is the same type as WebRTC’s RTCSdpType.
This type can hold an arbitrary string. To build this with a custom value, convert it from a
string with ::from() / .into(). To check for values that are not available as a
documented variant here, use its string representation, obtained through
.as_str().
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Answer
The description must be treated as an SDP final answer, and the offer-answer exchange must be considered complete.
Offer
The description must be treated as an SDP offer.
PrAnswer
Available on crate feature
unstable-msc2746 only.The description must be treated as an SDP answer, but not final.
Rollback
Available on crate feature
unstable-msc2746 only.The description must be treated as cancelling the current SDP negotiation and moving the SDP offer back to what it was in the previous stable state.
Implementations