Struct ruma_common::events::call::invite::CallInviteEventContent
source · pub struct CallInviteEventContent {
pub call_id: OwnedVoipId,
pub party_id: Option<OwnedVoipId>,
pub lifetime: UInt,
pub offer: OfferSessionDescription,
pub version: VoipVersionId,
pub capabilities: CallCapabilities,
pub invitee: Option<OwnedUserId>,
}events only.Expand description
The content of an m.call.invite event.
This event is sent by the caller when they wish to establish a call.
Fields
call_id: OwnedVoipIdA unique identifier for the call.
party_id: Option<OwnedVoipId>unstable-msc2746 only.Required in VoIP version 1. A unique ID for this session for the duration of the call.
lifetime: UIntThe time in milliseconds that the invite is valid for.
Once the invite age exceeds this value, clients should discard it. They should also no longer show the call as awaiting an answer in the UI.
offer: OfferSessionDescriptionThe session description object.
version: VoipVersionIdThe version of the VoIP specification this messages adheres to.
capabilities: CallCapabilitiesunstable-msc2746 only.Added in VoIP version 1. The VoIP capabilities of the client.
invitee: Option<OwnedUserId>unstable-msc2746 only.Added in VoIP version 1. The intended target of the invite, if any.
If this is None, the invite is intended for any member of the room, except the sender.
The invite should be ignored if the invitee is set and doesn’t match the user’s ID.
Implementations
sourceimpl CallInviteEventContent
impl CallInviteEventContent
sourcepub fn new(
call_id: OwnedVoipId,
lifetime: UInt,
offer: OfferSessionDescription,
version: VoipVersionId
) -> Self
pub fn new(
call_id: OwnedVoipId,
lifetime: UInt,
offer: OfferSessionDescription,
version: VoipVersionId
) -> Self
Creates a new CallInviteEventContent with the given call ID, lifetime, offer and VoIP
version.
sourcepub fn version_0(
call_id: OwnedVoipId,
lifetime: UInt,
offer: OfferSessionDescription
) -> Self
pub fn version_0(
call_id: OwnedVoipId,
lifetime: UInt,
offer: OfferSessionDescription
) -> Self
Convenience method to create a version 0 CallInviteEventContent with all the required
fields.
sourcepub fn version_1(
call_id: OwnedVoipId,
party_id: OwnedVoipId,
lifetime: UInt,
offer: OfferSessionDescription,
capabilities: CallCapabilities
) -> Self
Available on crate feature unstable-msc2746 only.
pub fn version_1(
call_id: OwnedVoipId,
party_id: OwnedVoipId,
lifetime: UInt,
offer: OfferSessionDescription,
capabilities: CallCapabilities
) -> Self
unstable-msc2746 only.Convenience method to create a version 1 CallInviteEventContent with all the required
fields.