pub enum AnyMessageLikeEvent {
Show 31 variants Audio(AudioEvent), CallAnswer(CallAnswerEvent), CallInvite(CallInviteEvent), CallHangup(CallHangupEvent), CallCandidates(CallCandidatesEvent), CallNegotiate(CallNegotiateEvent), CallReject(CallRejectEvent), CallSelectAnswer(CallSelectAnswerEvent), Emote(EmoteEvent), File(FileEvent), Image(ImageEvent), KeyVerificationReady(KeyVerificationReadyEvent), KeyVerificationStart(KeyVerificationStartEvent), KeyVerificationCancel(KeyVerificationCancelEvent), KeyVerificationAccept(KeyVerificationAcceptEvent), KeyVerificationKey(KeyVerificationKeyEvent), KeyVerificationMac(KeyVerificationMacEvent), KeyVerificationDone(KeyVerificationDoneEvent), Location(LocationEvent), Message(MessageEvent), Notice(NoticeEvent), PollStart(PollStartEvent), PollResponse(PollResponseEvent), PollEnd(PollEndEvent), Reaction(ReactionEvent), RoomEncrypted(RoomEncryptedEvent), RoomMessage(RoomMessageEvent), RoomRedaction(RoomRedactionEvent), Sticker(StickerEvent), Video(VideoEvent), Voice(VoiceEvent), // some variants omitted
}
Available on crate feature events only.
Any message-like event.

Variants



Audio(AudioEvent)

Available on crate feature unstable-msc3246 only.

m.audio



CallAnswer(CallAnswerEvent)

m.call.answer



CallInvite(CallInviteEvent)

m.call.invite



CallHangup(CallHangupEvent)

m.call.hangup



CallCandidates(CallCandidatesEvent)

m.call.candidates



CallNegotiate(CallNegotiateEvent)

Available on crate feature unstable-msc2746 only.

m.call.negotiate



CallReject(CallRejectEvent)

Available on crate feature unstable-msc2746 only.

m.call.reject



CallSelectAnswer(CallSelectAnswerEvent)

Available on crate feature unstable-msc2746 only.

m.call.select_answer



Emote(EmoteEvent)

Available on crate feature unstable-msc1767 only.

m.emote



File(FileEvent)

Available on crate feature unstable-msc3551 only.

m.file



Image(ImageEvent)

Available on crate feature unstable-msc3552 only.

m.image



KeyVerificationReady(KeyVerificationReadyEvent)

m.key.verification.ready



KeyVerificationStart(KeyVerificationStartEvent)

m.key.verification.start



KeyVerificationCancel(KeyVerificationCancelEvent)

m.key.verification.cancel



KeyVerificationAccept(KeyVerificationAcceptEvent)

m.key.verification.accept



KeyVerificationKey(KeyVerificationKeyEvent)

m.key.verification.key



KeyVerificationMac(KeyVerificationMacEvent)

m.key.verification.mac



KeyVerificationDone(KeyVerificationDoneEvent)

m.key.verification.done



Location(LocationEvent)

Available on crate feature unstable-msc3488 only.

m.location



Message(MessageEvent)

Available on crate feature unstable-msc1767 only.

m.message



Notice(NoticeEvent)

Available on crate feature unstable-msc1767 only.

m.notice



PollStart(PollStartEvent)

Available on crate feature unstable-msc3381 only.

m.poll.start

This variant uses the unstable type org.matrix.msc3381.poll.start.

This variant can also be deserialized from the m.poll.start type.



PollResponse(PollResponseEvent)

Available on crate feature unstable-msc3381 only.

m.poll.response

This variant uses the unstable type org.matrix.msc3381.poll.response.

This variant can also be deserialized from the m.poll.response type.



PollEnd(PollEndEvent)

Available on crate feature unstable-msc3381 only.

m.poll.end

This variant uses the unstable type org.matrix.msc3381.poll.end.

This variant can also be deserialized from the m.poll.end type.



Reaction(ReactionEvent)

Available on crate feature unstable-msc2677 only.

m.reaction



RoomEncrypted(RoomEncryptedEvent)

m.room.encrypted



RoomMessage(RoomMessageEvent)

m.room.message



RoomRedaction(RoomRedactionEvent)

m.room.redaction



Sticker(StickerEvent)

m.sticker



Video(VideoEvent)

Available on crate feature unstable-msc3553 only.

m.video



Voice(VoiceEvent)

Available on crate feature unstable-msc3245 only.

m.voice

Implementations

source

impl AnyMessageLikeEvent

source

pub fn event_type(&self) -> MessageLikeEventType

Returns the type of this event.

source

pub fn original_content(&self) -> Option<AnyMessageLikeEventContent>

Returns the content for this event if it is not redacted, or None if it is.

source

pub fn origin_server_ts(&self) -> MilliSecondsSinceUnixEpoch

Returns this event’s origin_server_ts field.

source

pub fn room_id(&self) -> &RoomId

Returns this event’s room_id field.

source

pub fn event_id(&self) -> &EventId

Returns this event’s event_id field.

source

pub fn sender(&self) -> &UserId

Returns this event’s sender field.

source

pub fn transaction_id(&self) -> Option<&TransactionId>

Returns this event’s transaction_id from inside unsigned, if there is one.

source

pub fn relations(&self) -> &BundledRelations

Returns this event’s relations from inside unsigned.