pub enum AnySyncMessageLikeEvent {
Show 31 variants Audio(SyncAudioEvent), CallAnswer(SyncCallAnswerEvent), CallInvite(SyncCallInviteEvent), CallHangup(SyncCallHangupEvent), CallCandidates(SyncCallCandidatesEvent), CallNegotiate(SyncCallNegotiateEvent), CallReject(SyncCallRejectEvent), CallSelectAnswer(SyncCallSelectAnswerEvent), Emote(SyncEmoteEvent), File(SyncFileEvent), Image(SyncImageEvent), KeyVerificationReady(SyncKeyVerificationReadyEvent), KeyVerificationStart(SyncKeyVerificationStartEvent), KeyVerificationCancel(SyncKeyVerificationCancelEvent), KeyVerificationAccept(SyncKeyVerificationAcceptEvent), KeyVerificationKey(SyncKeyVerificationKeyEvent), KeyVerificationMac(SyncKeyVerificationMacEvent), KeyVerificationDone(SyncKeyVerificationDoneEvent), Location(SyncLocationEvent), Message(SyncMessageEvent), Notice(SyncNoticeEvent), PollStart(SyncPollStartEvent), PollResponse(SyncPollResponseEvent), PollEnd(SyncPollEndEvent), Reaction(SyncReactionEvent), RoomEncrypted(SyncRoomEncryptedEvent), RoomMessage(SyncRoomMessageEvent), RoomRedaction(SyncRoomRedactionEvent), Sticker(SyncStickerEvent), Video(SyncVideoEvent), Voice(SyncVoiceEvent), // some variants omitted
}
Available on crate feature events only.
Any message-like event.

Variants



Audio(SyncAudioEvent)

Available on crate feature unstable-msc3246 only.

m.audio



CallAnswer(SyncCallAnswerEvent)

m.call.answer



CallInvite(SyncCallInviteEvent)

m.call.invite



CallHangup(SyncCallHangupEvent)

m.call.hangup



CallCandidates(SyncCallCandidatesEvent)

m.call.candidates



CallNegotiate(SyncCallNegotiateEvent)

Available on crate feature unstable-msc2746 only.

m.call.negotiate



CallReject(SyncCallRejectEvent)

Available on crate feature unstable-msc2746 only.

m.call.reject



CallSelectAnswer(SyncCallSelectAnswerEvent)

Available on crate feature unstable-msc2746 only.

m.call.select_answer



Emote(SyncEmoteEvent)

Available on crate feature unstable-msc1767 only.

m.emote



File(SyncFileEvent)

Available on crate feature unstable-msc3551 only.

m.file



Image(SyncImageEvent)

Available on crate feature unstable-msc3552 only.

m.image



KeyVerificationReady(SyncKeyVerificationReadyEvent)

m.key.verification.ready



KeyVerificationStart(SyncKeyVerificationStartEvent)

m.key.verification.start



KeyVerificationCancel(SyncKeyVerificationCancelEvent)

m.key.verification.cancel



KeyVerificationAccept(SyncKeyVerificationAcceptEvent)

m.key.verification.accept



KeyVerificationKey(SyncKeyVerificationKeyEvent)

m.key.verification.key



KeyVerificationMac(SyncKeyVerificationMacEvent)

m.key.verification.mac



KeyVerificationDone(SyncKeyVerificationDoneEvent)

m.key.verification.done



Location(SyncLocationEvent)

Available on crate feature unstable-msc3488 only.

m.location



Message(SyncMessageEvent)

Available on crate feature unstable-msc1767 only.

m.message



Notice(SyncNoticeEvent)

Available on crate feature unstable-msc1767 only.

m.notice



PollStart(SyncPollStartEvent)

Available on crate feature unstable-msc3381 only.

m.poll.start

This variant uses the unstable type org.matrix.msc3381.poll.start.

This variant can also be deserialized from the m.poll.start type.



PollResponse(SyncPollResponseEvent)

Available on crate feature unstable-msc3381 only.

m.poll.response

This variant uses the unstable type org.matrix.msc3381.poll.response.

This variant can also be deserialized from the m.poll.response type.



PollEnd(SyncPollEndEvent)

Available on crate feature unstable-msc3381 only.

m.poll.end

This variant uses the unstable type org.matrix.msc3381.poll.end.

This variant can also be deserialized from the m.poll.end type.



Reaction(SyncReactionEvent)

Available on crate feature unstable-msc2677 only.

m.reaction



RoomEncrypted(SyncRoomEncryptedEvent)

m.room.encrypted



RoomMessage(SyncRoomMessageEvent)

m.room.message



RoomRedaction(SyncRoomRedactionEvent)

m.room.redaction



Sticker(SyncStickerEvent)

m.sticker



Video(SyncVideoEvent)

Available on crate feature unstable-msc3553 only.

m.video



Voice(SyncVoiceEvent)

Available on crate feature unstable-msc3245 only.

m.voice

Implementations

source

impl AnySyncMessageLikeEvent

source

pub fn event_type(&self) -> MessageLikeEventType

Returns the type of this event.

source

pub fn original_content(&self) -> Option<AnyMessageLikeEventContent>

Returns the content for this event if it is not redacted, or None if it is.

source

pub fn origin_server_ts(&self) -> MilliSecondsSinceUnixEpoch

Returns this event’s origin_server_ts field.

source

pub fn event_id(&self) -> &EventId

Returns this event’s event_id field.

source

pub fn sender(&self) -> &UserId

Returns this event’s sender field.

source

pub fn transaction_id(&self) -> Option<&TransactionId>

Returns this event’s transaction_id from inside unsigned, if there is one.

source

pub fn relations(&self) -> &BundledRelations

Returns this event’s relations from inside unsigned.

source

impl AnySyncMessageLikeEvent

source

pub fn into_full_event(self, room_id: OwnedRoomId) -> AnyMessageLikeEvent

Convert this sync event into a full event (one with a room_id field).