Enum ruma_common::events::EventKind
source · [−]#[non_exhaustive]
pub enum EventKind {
GlobalAccountData,
RoomAccountData,
EphemeralRoomData,
MessageLike {
redacted: bool,
},
State {
redacted: bool,
},
ToDevice,
Presence,
}Available on crate feature
events only.Expand description
The “kind” of an event.
This corresponds directly to the event content marker traits.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
GlobalAccountData
Global account data event kind.
RoomAccountData
Room account data event kind.
EphemeralRoomData
Ephemeral room event kind.
MessageLike
Fields
redacted: boolRedacted variation?
Message-like event kind.
Since redacted / non-redacted message-like events are used in the same places but have different sets of fields, these two variations are treated as two closely-related event kinds.
State
Fields
redacted: boolRedacted variation?
State event kind.
Since redacted / non-redacted state events are used in the same places but have different sets of fields, these two variations are treated as two closely-related event kinds.
ToDevice
To-device event kind.
Presence
Presence event kind.