pub enum GlobalAccountDataEventType {
Direct,
IdentityServer,
IgnoredUserList,
PushRules,
SecretStorageDefaultKey,
SecretStorageKey(String),
// some variants omitted
}Available on crate feature
events only.Expand description
The type of GlobalAccountDataEvent this is.
This type can hold an arbitrary string. To build events with a custom type, convert it
from a string with ::from() / .into(). To check for events that are not available as a
documented variant here, use its string representation, obtained through .to_string().
Variants
Direct
m.direct
IdentityServer
m.identity_server
IgnoredUserList
m.ignored_user_list
PushRules
m.push_rules
SecretStorageDefaultKey
m.secret_storage.default_key
SecretStorageKey(String)
m.secret_storage.key.*