Enum ruma_common::events::TimelineEventType
source · pub enum TimelineEventType {
Show 52 variants
Audio,
CallAnswer,
CallInvite,
CallHangup,
CallCandidates,
CallNegotiate,
CallReject,
CallSelectAnswer,
Emote,
File,
Image,
KeyVerificationReady,
KeyVerificationStart,
KeyVerificationCancel,
KeyVerificationAccept,
KeyVerificationKey,
KeyVerificationMac,
KeyVerificationDone,
Location,
Message,
Notice,
PollStart,
PollResponse,
PollEnd,
Reaction,
RoomEncrypted,
RoomMessage,
RoomRedaction,
Sticker,
Video,
Voice,
PolicyRuleRoom,
PolicyRuleServer,
PolicyRuleUser,
RoomAliases,
RoomAvatar,
RoomCanonicalAlias,
RoomCreate,
RoomEncryption,
RoomGuestAccess,
RoomHistoryVisibility,
RoomJoinRules,
RoomMember,
RoomName,
RoomPinnedEvents,
RoomPowerLevels,
RoomServerAcl,
RoomThirdPartyInvite,
RoomTombstone,
RoomTopic,
SpaceChild,
SpaceParent,
// some variants omitted
}events only.Expand description
The type of TimelineEvent this is.
This type can hold an arbitrary string. To build events with a custom type, convert it
from a string with ::from() / .into(). To check for events that are not available as a
documented variant here, use its string representation, obtained through .to_string().
Variants
Audio
unstable-msc3246 only.m.audio
CallAnswer
m.call.answer
CallInvite
m.call.invite
CallHangup
m.call.hangup
CallCandidates
m.call.candidates
CallNegotiate
unstable-msc2746 only.m.call.negotiate
CallReject
unstable-msc2746 only.m.call.reject
CallSelectAnswer
unstable-msc2746 only.m.call.select_answer
Emote
unstable-msc1767 only.m.emote
File
unstable-msc3551 only.m.file
Image
unstable-msc3552 only.m.image
KeyVerificationReady
m.key.verification.ready
KeyVerificationStart
m.key.verification.start
KeyVerificationCancel
m.key.verification.cancel
KeyVerificationAccept
m.key.verification.accept
KeyVerificationKey
m.key.verification.key
KeyVerificationMac
m.key.verification.mac
KeyVerificationDone
m.key.verification.done
Location
unstable-msc3488 only.m.location
Message
unstable-msc1767 only.m.message
Notice
unstable-msc1767 only.m.notice
PollStart
unstable-msc3381 only.org.matrix.msc3381.poll.start
PollResponse
unstable-msc3381 only.org.matrix.msc3381.poll.response
PollEnd
unstable-msc3381 only.org.matrix.msc3381.poll.end
Reaction
unstable-msc2677 only.m.reaction
RoomEncrypted
m.room.encrypted
RoomMessage
m.room.message
RoomRedaction
m.room.redaction
Sticker
m.sticker
Video
unstable-msc3553 only.m.video
Voice
unstable-msc3245 only.m.voice
PolicyRuleRoom
m.policy.rule.room
PolicyRuleServer
m.policy.rule.server
PolicyRuleUser
m.policy.rule.user
RoomAliases
m.room.aliases
RoomAvatar
m.room.avatar
RoomCanonicalAlias
m.room.canonical_alias
RoomCreate
m.room.create
RoomEncryption
m.room.encryption
RoomGuestAccess
m.room.guest_access
RoomHistoryVisibility
m.room.history_visibility
RoomJoinRules
m.room.join_rules
RoomMember
m.room.member
RoomName
m.room.name
RoomPinnedEvents
m.room.pinned_events
RoomPowerLevels
m.room.power_levels
RoomServerAcl
m.room.server_acl
RoomThirdPartyInvite
m.room.third_party_invite
RoomTombstone
m.room.tombstone
RoomTopic
m.room.topic
SpaceChild
m.space.child
SpaceParent
m.space.parent