Struct ruma_common::events::file::EncryptedContent
source · pub struct EncryptedContent {
pub key: JsonWebKey,
pub iv: Base64,
pub hashes: BTreeMap<String, Base64>,
pub v: String,
}Available on crate features
events and unstable-msc3551 only.Expand description
The encryption info of a file sent to a room with end-to-end encryption enabled.
To create an instance of this type, first create a EncryptedContentInit and convert it via
EncryptedContent::from / .into().
Fields
key: JsonWebKeyA JSON Web Key object.
iv: Base64The 128-bit unique counter block used by AES-CTR, encoded as unpadded base64.
hashes: BTreeMap<String, Base64>A map from an algorithm name to a hash of the ciphertext, encoded as unpadded base64.
Clients should support the SHA-256 hash, which uses the key sha256.
v: StringVersion of the encrypted attachments protocol.
Must be v2.