Struct ruma_common::events::file::EncryptedContentInit
source · pub struct EncryptedContentInit {
pub key: JsonWebKey,
pub iv: Base64,
pub hashes: BTreeMap<String, Base64>,
pub v: String,
}Available on crate features
events and unstable-msc3551 only.Expand description
Initial set of fields of EncryptedContent.
This struct will not be updated even if additional fields are added to EncryptedContent in a
new (non-breaking) release of the Matrix specification.
Fields
key: JsonWebKeyA JSON Web Key object.
iv: Base64The 128-bit unique counter block used by AES-CTR, encoded as unpadded base64.
hashes: BTreeMap<String, Base64>A map from an algorithm name to a hash of the ciphertext, encoded as unpadded base64.
Clients should support the SHA-256 hash, which uses the key sha256.
v: StringVersion of the encrypted attachments protocol.
Must be v2.