pub struct ToDeviceForwardedRoomKeyEventContentInit {
    pub algorithm: EventEncryptionAlgorithm,
    pub room_id: OwnedRoomId,
    pub sender_key: String,
    pub session_id: String,
    pub session_key: String,
    pub sender_claimed_ed25519_key: String,
    pub forwarding_curve25519_key_chain: Vec<String>,
}
Available on crate feature events only.
Initial set of fields of ToDeviceForwardedRoomKeyEventContent.

This struct will not be updated even if additional fields are added to ConditionalPushRule in a new (non-breaking) release of the Matrix specification.

Fields

algorithm: EventEncryptionAlgorithm

The encryption algorithm the key in this event is to be used with.

room_id: OwnedRoomId

The room where the key is used.

sender_key: String

The Curve25519 key of the device which initiated the session originally.

session_id: String

The ID of the session that the key is for.

session_key: String

The key to be exchanged.

sender_claimed_ed25519_key: String

The Ed25519 key of the device which initiated the session originally.

It is “claimed” because the receiving device has no way to tell that the original room_key actually came from a device which owns the private part of this key unless they have done device verification.

forwarding_curve25519_key_chain: Vec<String>

Chain of Curve25519 keys.

It starts out empty, but each time the key is forwarded to another device, the previous sender in the chain is added to the end of the list. For example, if the key is forwarded from A to B to C, this field is empty between A and B, and contains A’s Curve25519 key between B and C.