Struct ruma_common::events::fully_read::FullyReadEventContent
source · pub struct FullyReadEventContent {
pub event_id: OwnedEventId,
}Available on crate feature
events only.Expand description
The content of an m.fully_read event.
The current location of the user’s read marker in a room.
This event appears in the user’s room account data for the room the marker is applicable for.
Fields
event_id: OwnedEventIdThe event the user’s read marker is located at in the room.
Implementations
sourceimpl FullyReadEventContent
impl FullyReadEventContent
sourcepub fn new(event_id: OwnedEventId) -> Self
pub fn new(event_id: OwnedEventId) -> Self
Creates a new FullyReadEventContent with the given event ID.