Struct ruma_common::events::key::verification::done::ToDeviceKeyVerificationDoneEventContent
source · pub struct ToDeviceKeyVerificationDoneEventContent {
pub transaction_id: OwnedTransactionId,
}Available on crate feature
events only.Expand description
The content of a to-device m.m.key.verification.done event.
Event signaling that the interactive key verification has successfully concluded.
Fields
transaction_id: OwnedTransactionIdAn opaque identifier for the verification process.
Must be the same as the one used for the m.key.verification.start message.
Implementations
sourceimpl ToDeviceKeyVerificationDoneEventContent
impl ToDeviceKeyVerificationDoneEventContent
sourcepub fn new(transaction_id: OwnedTransactionId) -> Self
pub fn new(transaction_id: OwnedTransactionId) -> Self
Creates a new ToDeviceKeyVerificationDoneEventContent with the given transaction ID.