#[non_exhaustive]
pub enum HashAlgorithm {
    Sha256,
    // some variants omitted
}
Available on crate feature events only.
A hash algorithm.

This type can hold an arbitrary string. To build this with a custom value, convert it from a string with ::from() / .into(). To check for values that are not available as a documented variant here, use its string representation, obtained through .as_str().

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


Sha256

The SHA256 hash algorithm.

Implementations

source

impl HashAlgorithm

source

pub fn as_str(&self) -> &str

Creates a string slice from this HashAlgorithm.