Struct ruma_common::events::key::verification::key::ToDeviceKeyVerificationKeyEventContent
source · [−]pub struct ToDeviceKeyVerificationKeyEventContent {
pub transaction_id: OwnedTransactionId,
pub key: Base64,
}events only.Expand description
The content of a to-device m.key.verification.key event.
Sends the ephemeral public key for a device to the partner device.
Fields
transaction_id: OwnedTransactionIdAn opaque identifier for the verification process.
Must be the same as the one used for the m.key.verification.start message.
key: Base64The device’s ephemeral public key, encoded as unpadded base64.
Implementations
sourceimpl ToDeviceKeyVerificationKeyEventContent
impl ToDeviceKeyVerificationKeyEventContent
sourcepub fn new(transaction_id: OwnedTransactionId, key: Base64) -> Self
pub fn new(transaction_id: OwnedTransactionId, key: Base64) -> Self
Creates a new ToDeviceKeyVerificationKeyEventContent with the given transaction ID and
key.