pub struct ToDeviceKeyVerificationMacEventContent {
pub transaction_id: OwnedTransactionId,
pub mac: BTreeMap<String, Base64>,
pub keys: Base64,
}Available on crate feature
events only.Expand description
The content of a to-device m.key.verification. event.
Sends the MAC of a device’s key to the partner device.
Fields
transaction_id: OwnedTransactionIdAn opaque identifier for the verification process.
Must be the same as the one used for the m.key.verification.start message.
mac: BTreeMap<String, Base64>A map of the key ID to the MAC of the key, using the algorithm in the verification process.
The MAC is encoded as unpadded base64.
keys: Base64The MAC of the comma-separated, sorted, list of key IDs given in the mac property,
encoded as unpadded base64.
Implementations