Struct ruma_common::events::key::verification::request::ToDeviceKeyVerificationRequestEventContent
source · pub struct ToDeviceKeyVerificationRequestEventContent {
pub from_device: OwnedDeviceId,
pub transaction_id: OwnedTransactionId,
pub methods: Vec<VerificationMethod>,
pub timestamp: MilliSecondsSinceUnixEpoch,
}Available on crate feature
events only.Expand description
The content of an m.key.verification.request event.
Fields
from_device: OwnedDeviceIdThe device ID which is initiating the request.
transaction_id: OwnedTransactionIdAn opaque identifier for the verification request.
Must be unique with respect to the devices involved.
methods: Vec<VerificationMethod>The verification methods supported by the sender.
timestamp: MilliSecondsSinceUnixEpochThe time in milliseconds for when the request was made.
If the request is in the future by more than 5 minutes or more than 10 minutes in the past, the message should be ignored by the receiver.
Implementations
sourceimpl ToDeviceKeyVerificationRequestEventContent
impl ToDeviceKeyVerificationRequestEventContent
sourcepub fn new(
from_device: OwnedDeviceId,
transaction_id: OwnedTransactionId,
methods: Vec<VerificationMethod>,
timestamp: MilliSecondsSinceUnixEpoch
) -> Self
pub fn new(
from_device: OwnedDeviceId,
transaction_id: OwnedTransactionId,
methods: Vec<VerificationMethod>,
timestamp: MilliSecondsSinceUnixEpoch
) -> Self
Creates a new ToDeviceKeyVerificationRequestEventContent with the given device ID,
transaction ID, methods and timestamp.