#[non_exhaustive]
pub enum AssetType {
Self_,
// some variants omitted
}events and unstable-msc3488 only.Expand description
The type of an asset.
This type can hold an arbitrary string. To build this with a custom value, convert it from a
string with ::from() / .into(). To check for formats that are not available as a
documented variant here, use its string representation, obtained through .as_str().
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Self_
The asset is the sender of the event.