Struct ruma_common::events::poll::end::PollEndEventContent
source · pub struct PollEndEventContent {
pub poll_end: PollEndContent,
pub relates_to: Reference,
}Available on crate features
events and unstable-msc3381 only.Expand description
The payload for a poll end event.
Fields
poll_end: PollEndContentThe poll end content of the message.
relates_to: ReferenceInformation about the poll start event this responds to.
Implementations
sourceimpl PollEndEventContent
impl PollEndEventContent
sourcepub fn new(poll_end: PollEndContent, poll_start_id: OwnedEventId) -> Self
pub fn new(poll_end: PollEndContent, poll_start_id: OwnedEventId) -> Self
Creates a new PollEndEventContent that responds to the given poll start event ID,
with the given poll end content.