Struct ruma_common::events::poll::response::PollResponseEventContent
source · pub struct PollResponseEventContent {
pub poll_response: PollResponseContent,
pub relates_to: Reference,
}Available on crate features
events and unstable-msc3381 only.Expand description
The payload for a poll response event.
Fields
poll_response: PollResponseContentThe poll response content of the message.
relates_to: ReferenceInformation about the poll start event this responds to.
Implementations
sourceimpl PollResponseEventContent
impl PollResponseEventContent
sourcepub fn new(
poll_response: PollResponseContent,
poll_start_id: OwnedEventId
) -> Self
pub fn new(
poll_response: PollResponseContent,
poll_start_id: OwnedEventId
) -> Self
Creates a new PollResponseEventContent that responds to the given poll start event ID,
with the given poll response content.