pub struct Relation {
pub event_id: OwnedEventId,
pub key: String,
}Available on crate features
events and unstable-msc2677 only.Expand description
Information about an annotation relation.
Fields
event_id: OwnedEventIdThe event that is being annotated.
key: StringA string that indicates the annotation being applied.
When sending emoji reactions, this field should include the colourful variation-16 when applicable.
Clients should render reactions that have a long key field in a sensible manner.
Implementations