Enum ruma_common::events::relation::AnnotationType
source · pub enum AnnotationType {
Reaction,
// some variants omitted
}Available on crate features
events and unstable-msc2677 only.Expand description
Type of annotation.
This type can hold an arbitrary string. To build this with a custom value, convert it from a
string with ::from() / .into(). To check for values that are not available as a
documented variant here, use its string representation, obtained through
.as_str().
Variants
Reaction
A reaction.
Implementations