Struct ruma_common::events::relation::Annotation
source · pub struct Annotation {
pub event_id: OwnedEventId,
pub key: String,
}Available on crate features
events and unstable-msc2677 only.Expand description
An annotation for an event.
Fields
event_id: OwnedEventIdThe event that is being annotated.
key: StringA string that indicates the annotation being applied.
When sending emoji reactions, this field should include the colourful variation-16 when applicable.
Clients should render reactions that have a long key field in a sensible manner.
Implementations
sourceimpl Annotation
impl Annotation
sourcepub fn new(event_id: OwnedEventId, key: String) -> Self
pub fn new(event_id: OwnedEventId, key: String) -> Self
Creates a new Annotation with the given event ID and key.