Struct ruma_common::events::relation::Thread
source · pub struct Thread {
pub event_id: OwnedEventId,
pub in_reply_to: InReplyTo,
pub is_falling_back: bool,
}Available on crate feature
events only.Expand description
The content of a thread relation.
Fields
event_id: OwnedEventIdThe ID of the root message in the thread.
in_reply_to: InReplyToA reply relation.
If this event is a reply and belongs to a thread, this points to the message that is being
replied to, and is_falling_back must be set to false.
If this event is not a reply, this is used as a fallback mechanism for clients that do not
support threads. This should point to the latest message-like event in the thread and
is_falling_back must be set to true.
is_falling_back: boolWhether the m.in_reply_to field is a fallback for older clients or a genuine reply in a
thread.
Implementations
sourceimpl Thread
impl Thread
sourcepub fn plain(event_id: OwnedEventId, latest_event_id: OwnedEventId) -> Self
pub fn plain(event_id: OwnedEventId, latest_event_id: OwnedEventId) -> Self
Convenience method to create a regular Thread with the given event ID and latest
message-like event ID.
sourcepub fn reply(event_id: OwnedEventId, reply_to_event_id: OwnedEventId) -> Self
pub fn reply(event_id: OwnedEventId, reply_to_event_id: OwnedEventId) -> Self
Convenience method to create a reply Thread with the given event ID and replied-to event
ID.