Struct ruma_common::events::room::create::RoomCreateEventContent
source · pub struct RoomCreateEventContent {
pub creator: OwnedUserId,
pub federate: bool,
pub room_version: RoomVersionId,
pub predecessor: Option<PreviousRoom>,
pub room_type: Option<RoomType>,
}Available on crate feature
events only.Expand description
The content of an m.room.create event.
This is the first event in a room and cannot be changed.
It acts as the root of all other events.
Fields
creator: OwnedUserIdThe user_id of the room creator.
This is set by the homeserver.
federate: boolWhether or not this room’s data should be transferred to other homeservers.
room_version: RoomVersionIdThe version of the room.
Defaults to RoomVersionId::V1.
predecessor: Option<PreviousRoom>A reference to the room this room replaces, if the previous room was upgraded.
room_type: Option<RoomType>The room type.
This is currently only used for spaces.
Implementations
sourceimpl RoomCreateEventContent
impl RoomCreateEventContent
sourcepub fn new(creator: OwnedUserId) -> Self
pub fn new(creator: OwnedUserId) -> Self
Creates a new RoomCreateEventContent with the given creator.