pub struct PossiblyRedactedRoomEncryptionEventContent {
pub algorithm: Option<EventEncryptionAlgorithm>,
pub rotation_period_ms: Option<UInt>,
pub rotation_period_msgs: Option<UInt>,
}Available on crate feature
events only.Expand description
The possibly redacted form of RoomEncryptionEventContent.
This type is used when it’s not obvious whether the content is redacted or not.
Fields
algorithm: Option<EventEncryptionAlgorithm>The encryption algorithm to be used to encrypt messages sent in this room.
Must be m.megolm.v1.aes-sha2.
rotation_period_ms: Option<UInt>How long the session should be used before changing it.
uint!(604800000) (a week) is the recommended default.
rotation_period_msgs: Option<UInt>How many messages should be sent before changing the session.
uint!(100) is the recommended default.