Struct ruma_common::events::room::encryption::RoomEncryptionEventContent
source · pub struct RoomEncryptionEventContent {
pub algorithm: EventEncryptionAlgorithm,
pub rotation_period_ms: Option<UInt>,
pub rotation_period_msgs: Option<UInt>,
}Available on crate feature
events only.Expand description
The content of an m.room.encryption event.
Defines how messages sent in this room should be encrypted.
Fields
algorithm: EventEncryptionAlgorithmThe encryption algorithm to be used to encrypt messages sent in this room.
Must be m.megolm.v1.aes-sha2.
rotation_period_ms: Option<UInt>How long the session should be used before changing it.
uint!(604800000) (a week) is the recommended default.
rotation_period_msgs: Option<UInt>How many messages should be sent before changing the session.
uint!(100) is the recommended default.
Implementations
sourceimpl RoomEncryptionEventContent
impl RoomEncryptionEventContent
sourcepub fn new(algorithm: EventEncryptionAlgorithm) -> Self
pub fn new(algorithm: EventEncryptionAlgorithm) -> Self
Creates a new RoomEncryptionEventContent with the given algorithm.