Enum ruma_common::events::room::join_rules::AllowRule
source · pub enum AllowRule {
RoomMembership(RoomMembership),
// some variants omitted
}Available on crate feature
events only.Expand description
An allow rule which defines a condition that allows joining a room.
Variants
RoomMembership(RoomMembership)
Joining is allowed if a user is already a member of the room with the id room_id.
Implementations
sourceimpl AllowRule
impl AllowRule
sourcepub fn room_membership(room_id: OwnedRoomId) -> Self
pub fn room_membership(room_id: OwnedRoomId) -> Self
Constructs an AllowRule with membership of the room with the given id as its predicate.