Enum ruma_common::events::room::join_rules::JoinRule
source · [−]pub enum JoinRule {
Invite,
Knock,
Private,
Restricted(Restricted),
KnockRestricted(Restricted),
Public,
// some variants omitted
}events only.Expand description
The rule used for users wishing to join this room.
This type can hold an arbitrary string. To check for values that are not available as a
documented variant here, use its string representation, obtained through .as_str().
Variants
Invite
A user who wishes to join the room must first receive an invite to the room from someone already inside of the room.
Knock
Users can join the room if they are invited, or they can request an invite to the room.
They can be allowed (invited) or denied (kicked/banned) access.
Private
Reserved but not yet implemented by the Matrix specification.
Restricted(Restricted)
Users can join the room if they are invited, or if they meet any of the conditions
described in a set of AllowRules.
KnockRestricted(Restricted)
Users can join the room if they are invited, or if they meet any of the conditions
described in a set of AllowRules, or they can request an invite to the room.
Public
Anyone can join the room without any prior action.
Implementations