Struct ruma_common::events::room::join_rules::RoomJoinRulesEventContent
source · pub struct RoomJoinRulesEventContent {
pub join_rule: JoinRule,
}Available on crate feature
events only.Expand description
The content of an m.room.join_rules event.
Describes how users are allowed to join the room.
Fields
join_rule: JoinRuleThe type of rules used for users wishing to join this room.
Implementations
sourceimpl RoomJoinRulesEventContent
impl RoomJoinRulesEventContent
sourcepub fn new(join_rule: JoinRule) -> Self
pub fn new(join_rule: JoinRule) -> Self
Creates a new RoomJoinRulesEventContent with the given rule.
sourcepub fn restricted(allow: Vec<AllowRule>) -> Self
pub fn restricted(allow: Vec<AllowRule>) -> Self
Creates a new RoomJoinRulesEventContent with the restricted rule and the given set of
allow rules.
sourcepub fn knock_restricted(allow: Vec<AllowRule>) -> Self
pub fn knock_restricted(allow: Vec<AllowRule>) -> Self
Creates a new RoomJoinRulesEventContent with the knock restricted rule and the given set
of allow rules.