Enum ruma_common::events::room::message::ForwardThread
source · [−]pub enum ForwardThread {
Yes,
No,
}Available on crate features
events and unstable-msc3440 only.Expand description
Whether or not to forward a Relation::Thread when sending a reply.
Variants
Yes
The thread relation in the original message is forwarded if it exists.
This should be set if your client doesn’t support threads (see MSC3440).
No
Create a reply in the main conversation even if the original message is in a thread.
This should be used if you client supports threads and you explicitly want that behavior.