Enum ruma_common::events::room::message::ReplyWithinThread
source · pub enum ReplyWithinThread {
Yes,
No,
}Available on crate feature
events only.Expand description
Whether or not the message is a reply inside a thread.
Variants
Yes
This is a reply.
Create a reply within the thread.
No
This is not a reply.
Create a regular message in the thread, with a fallback for unthreaded clients.