Struct ruma_common::events::room::message::EmoteMessageEventContent
source · pub struct EmoteMessageEventContent {
pub body: String,
pub formatted: Option<FormattedBody>,
pub message: Option<MessageContent>,
}Available on crate feature
events only.Expand description
The payload for an emote message.
With the unstable-msc1767 feature, this type contains the transitional format of
EmoteEventContent. See the documentation of the message module for more information.
Fields
body: StringThe emote action to perform.
formatted: Option<FormattedBody>Formatted form of the message body.
message: Option<MessageContent>Available on crate feature
unstable-msc1767 only.Extensible-event representation of the message.
If present, this should be preferred over the other fields.
Implementations