Struct ruma_common::events::room::message::FormattedBody
source · pub struct FormattedBody {
pub format: MessageFormat,
pub body: String,
}Available on crate feature
events only.Expand description
Common message event content fields for message types that have separate plain-text and formatted representations.
Fields
format: MessageFormatThe format used in the formatted_body.
body: StringThe formatted version of the body.
Implementations
sourceimpl FormattedBody
impl FormattedBody
sourcepub fn markdown(body: impl AsRef<str>) -> Option<Self>
Available on crate feature markdown only.
pub fn markdown(body: impl AsRef<str>) -> Option<Self>
markdown only.Creates a new HTML-formatted message body by parsing the Markdown in body.
Returns None if no Markdown formatting was found.
sourcepub fn sanitize_html(
&mut self,
mode: HtmlSanitizerMode,
remove_reply_fallback: RemoveReplyFallback
)
Available on crate feature unstable-sanitize only.
pub fn sanitize_html( &mut self, mode: HtmlSanitizerMode, remove_reply_fallback: RemoveReplyFallback )
unstable-sanitize only.Sanitize this FormattedBody if its format is MessageFormat::Html.
This removes any tags and attributes that are not listed in the Matrix specification.
It can also optionally remove the rich reply fallback.
Returns the sanitized HTML if the format is MessageFormat::Html.