Struct ruma_common::events::room::message::ImageMessageEventContent
source · pub struct ImageMessageEventContent {
pub body: String,
pub source: MediaSource,
pub info: Option<Box<ImageInfo>>,
}Available on crate feature
events only.Expand description
The payload for an image message.
Fields
body: StringA textual representation of the image.
Could be the alt text of the image, the filename of the image, or some kind of content description for accessibility e.g. “image attachment”.
source: MediaSourceThe source of the image.
info: Option<Box<ImageInfo>>Metadata about the image referred to in source.
Implementations
sourceimpl ImageMessageEventContent
impl ImageMessageEventContent
sourcepub fn plain(body: String, url: OwnedMxcUri, info: Option<Box<ImageInfo>>) -> Self
pub fn plain(body: String, url: OwnedMxcUri, info: Option<Box<ImageInfo>>) -> Self
Creates a new non-encrypted ImageMessageEventContent with the given body, url and
optional extra info.
sourcepub fn encrypted(body: String, file: EncryptedFile) -> Self
pub fn encrypted(body: String, file: EncryptedFile) -> Self
Creates a new encrypted ImageMessageEventContent with the given body and encrypted
file.