Struct ruma_common::events::room::message::LocationMessageEventContent
source · pub struct LocationMessageEventContent {
pub body: String,
pub geo_uri: String,
pub info: Option<Box<LocationInfo>>,
pub message: Option<MessageContent>,
pub location: Option<LocationContent>,
pub asset: Option<AssetContent>,
pub ts: Option<MilliSecondsSinceUnixEpoch>,
}Available on crate feature
events only.Expand description
The payload for a location message.
With the unstable-msc3488 feature, this type contains the transitional format of
LocationEventContent. See the documentation of the message module for more information.
Fields
body: StringA description of the location e.g. “Big Ben, London, UK”, or some kind of content description for accessibility, e.g. “location attachment”.
geo_uri: StringA geo URI representing the location.
info: Option<Box<LocationInfo>>Info about the location being represented.
message: Option<MessageContent>Available on crate feature
unstable-msc3488 only.Extensible-event text representation of the message.
If present, this should be preferred over the body field.
location: Option<LocationContent>Available on crate feature
unstable-msc3488 only.Extensible-event location info of the message.
If present, this should be preferred over the geo_uri field.
asset: Option<AssetContent>Available on crate feature
unstable-msc3488 only.Extensible-event asset this message refers to.
ts: Option<MilliSecondsSinceUnixEpoch>Available on crate feature
unstable-msc3488 only.Extensible-event timestamp this message refers to.
Implementations