Struct ruma_common::events::room::message::ServerNoticeMessageEventContent
source · pub struct ServerNoticeMessageEventContent {
pub body: String,
pub server_notice_type: ServerNoticeType,
pub admin_contact: Option<String>,
pub limit_type: Option<LimitType>,
}Available on crate feature
events only.Expand description
The payload for a server notice message.
Fields
body: StringA human-readable description of the notice.
server_notice_type: ServerNoticeTypeThe type of notice being represented.
admin_contact: Option<String>A URI giving a contact method for the server administrator.
Required if the notice type is m.server_notice.usage_limit_reached.
limit_type: Option<LimitType>The kind of usage limit the server has exceeded.
Required if the notice type is m.server_notice.usage_limit_reached.
Implementations
sourceimpl ServerNoticeMessageEventContent
impl ServerNoticeMessageEventContent
sourcepub fn new(body: String, server_notice_type: ServerNoticeType) -> Self
pub fn new(body: String, server_notice_type: ServerNoticeType) -> Self
Creates a new ServerNoticeMessageEventContent with the given body and notice type.