Struct ruma_common::events::room_key::ToDeviceRoomKeyEventContent
source · pub struct ToDeviceRoomKeyEventContent {
pub algorithm: EventEncryptionAlgorithm,
pub room_id: OwnedRoomId,
pub session_id: String,
pub session_key: String,
}Available on crate feature
events only.Expand description
The content of an m.room_key event.
Typically encrypted as an m.room.encrypted event, then sent as a to-device event.
Fields
algorithm: EventEncryptionAlgorithmThe encryption algorithm the key in this event is to be used with.
Must be m.megolm.v1.aes-sha2.
room_id: OwnedRoomIdThe room where the key is used.
session_id: StringThe ID of the session that the key is for.
session_key: StringThe key to be exchanged.
Implementations
sourceimpl ToDeviceRoomKeyEventContent
impl ToDeviceRoomKeyEventContent
sourcepub fn new(
algorithm: EventEncryptionAlgorithm,
room_id: OwnedRoomId,
session_id: String,
session_key: String
) -> Self
pub fn new(
algorithm: EventEncryptionAlgorithm,
room_id: OwnedRoomId,
session_id: String,
session_key: String
) -> Self
Creates a new ToDeviceRoomKeyEventContent with the given algorithm, room ID, session ID
and session key.