Struct ruma_common::events::room_key_request::RequestedKeyInfo
source · pub struct RequestedKeyInfo {
pub algorithm: EventEncryptionAlgorithm,
pub room_id: OwnedRoomId,
pub sender_key: String,
pub session_id: String,
}Available on crate feature
events only.Expand description
Information about a requested key.
Fields
algorithm: EventEncryptionAlgorithmThe encryption algorithm the requested key in this event is to be used with.
room_id: OwnedRoomIdThe room where the key is used.
sender_key: String👎Deprecated: this field still needs to be sent but should not be used when received
The Curve25519 key of the device which initiated the session originally.
session_id: StringThe ID of the session that the key is for.
Implementations
sourceimpl RequestedKeyInfo
impl RequestedKeyInfo
sourcepub fn new(
algorithm: EventEncryptionAlgorithm,
room_id: OwnedRoomId,
sender_key: String,
session_id: String
) -> Self
pub fn new(
algorithm: EventEncryptionAlgorithm,
room_id: OwnedRoomId,
sender_key: String,
session_id: String
) -> Self
Creates a new RequestedKeyInfo with the given algorithm, room ID, sender key and session
ID.