pub struct ToDeviceRoomKeyRequestEventContent {
pub action: Action,
pub body: Option<RequestedKeyInfo>,
pub requesting_device_id: OwnedDeviceId,
pub request_id: OwnedTransactionId,
}Available on crate feature
events only.Expand description
The content of an m.room_key_request event.
Fields
action: ActionWhether this is a new key request or a cancellation of a previous request.
body: Option<RequestedKeyInfo>Information about the requested key.
Required if action is request.
requesting_device_id: OwnedDeviceIdID of the device requesting the key.
request_id: OwnedTransactionIdA random string uniquely identifying the request for a key.
If the key is requested multiple times, it should be reused. It should also reused in order to cancel a request.
Implementations
sourceimpl ToDeviceRoomKeyRequestEventContent
impl ToDeviceRoomKeyRequestEventContent
sourcepub fn new(
action: Action,
body: Option<RequestedKeyInfo>,
requesting_device_id: OwnedDeviceId,
request_id: OwnedTransactionId
) -> Self
pub fn new(
action: Action,
body: Option<RequestedKeyInfo>,
requesting_device_id: OwnedDeviceId,
request_id: OwnedTransactionId
) -> Self
Creates a new ToDeviceRoomKeyRequestEventContent with the given action, boyd, device ID
and request ID.