pub struct ToDeviceSecretRequestEventContent {
pub action: RequestAction,
pub requesting_device_id: OwnedDeviceId,
pub request_id: OwnedTransactionId,
}Available on crate feature
events only.Expand description
The content of an m.secret.request event.
Event sent by a client to request a secret from another device or to cancel a previous request.
It is sent as an unencrypted to-device event.
Fields
action: RequestActionThe action for the request.
requesting_device_id: OwnedDeviceIdThe ID of the device requesting the event.
request_id: OwnedTransactionIdA random string uniquely identifying (with respect to the requester and the target) the target for a secret.
If the secret is requested from multiple devices at the same time, the same ID may be used for every target. The same ID is also used in order to cancel a previous request.
Implementations
sourceimpl ToDeviceSecretRequestEventContent
impl ToDeviceSecretRequestEventContent
sourcepub fn new(
action: RequestAction,
requesting_device_id: OwnedDeviceId,
request_id: OwnedTransactionId
) -> Self
pub fn new(
action: RequestAction,
requesting_device_id: OwnedDeviceId,
request_id: OwnedTransactionId
) -> Self
Creates a new ToDeviceRequestEventContent with the given action, requesting device ID and
request ID.