Struct ruma_common::events::secret::send::ToDeviceSecretSendEventContent
source · pub struct ToDeviceSecretSendEventContent {
pub request_id: OwnedTransactionId,
pub secret: String,
}Available on crate feature
events only.Expand description
The content of an m.secret.send event.
An event sent by a client to share a secret with another device, in response to an
m.secret.request event.
It must be encrypted as an m.room.encrypted event, then sent as a to-device event.
Fields
request_id: OwnedTransactionIdThe ID of the request that this is a response to.
secret: StringThe contents of the secret.
Implementations
sourceimpl ToDeviceSecretSendEventContent
impl ToDeviceSecretSendEventContent
sourcepub fn new(request_id: OwnedTransactionId, secret: String) -> Self
pub fn new(request_id: OwnedTransactionId, secret: String) -> Self
Creates a new SecretSendEventContent with the given request ID and secret.