Struct ruma_common::events::sticker::StickerEventContent
source · pub struct StickerEventContent {
pub body: String,
pub info: ImageInfo,
pub url: OwnedMxcUri,
}Available on crate feature
events only.Expand description
The content of an m.sticker event.
A sticker message.
Fields
body: StringA textual representation or associated description of the sticker image.
This could be the alt text of the original image, or a message to accompany and further describe the sticker.
info: ImageInfoMetadata about the image referred to in url including a thumbnail representation.
url: OwnedMxcUriThe URL to the sticker image.
Implementations
sourceimpl StickerEventContent
impl StickerEventContent
sourcepub fn new(body: String, info: ImageInfo, url: OwnedMxcUri) -> Self
pub fn new(body: String, info: ImageInfo, url: OwnedMxcUri) -> Self
Creates a new StickerEventContent with the given body, image info and URL.