Struct ruma_common::events::MessageLikeUnsigned
source · pub struct MessageLikeUnsigned {
pub age: Option<Int>,
pub transaction_id: Option<OwnedTransactionId>,
pub relations: BundledRelations,
}events only.Expand description
Extra information about a message event that is not incorporated into the event’s hash.
Fields
age: Option<Int>The time in milliseconds that has elapsed since the event was sent.
This field is generated by the local homeserver, and may be incorrect if the local time on at least one of the two servers is out of sync, which can cause the age to either be negative or greater than it actually is.
transaction_id: Option<OwnedTransactionId>The client-supplied transaction ID, if the client being given the event is the same one which sent it.
relations: BundledRelationsBundled aggregations of related child events.
Implementations