Struct ruma_common::events::OriginalSyncMessageLikeEvent
source · [−]pub struct OriginalSyncMessageLikeEvent<C: MessageLikeEventContent> {
pub content: C,
pub event_id: OwnedEventId,
pub sender: OwnedUserId,
pub origin_server_ts: MilliSecondsSinceUnixEpoch,
pub unsigned: MessageLikeUnsigned,
}Available on crate feature
events only.Expand description
An unredacted message-like event without a room_id.
OriginalSyncMessageLikeEvent implements the comparison traits using only the event_id field,
a sorted list would be sorted lexicographically based on the event’s EventId.
Fields
content: CData specific to the event type.
event_id: OwnedEventIdThe globally unique event identifier for the user who sent the event.
sender: OwnedUserIdThe fully-qualified ID of the user who sent this event.
origin_server_ts: MilliSecondsSinceUnixEpochTimestamp in milliseconds on originating homeserver when this event was sent.
unsigned: MessageLikeUnsignedAdditional key-value pairs not signed by the homeserver.
Implementations
sourceimpl<C: MessageLikeEventContent> OriginalSyncMessageLikeEvent<C>
impl<C: MessageLikeEventContent> OriginalSyncMessageLikeEvent<C>
sourcepub fn into_full_event(self, room_id: OwnedRoomId) -> OriginalMessageLikeEvent<C>
pub fn into_full_event(self, room_id: OwnedRoomId) -> OriginalMessageLikeEvent<C>
Convert this sync event into a full event, one with a room_id field.