Struct ruma_common::events::StateUnsigned
source · [−]pub struct StateUnsigned<C: StateEventContent> {
pub age: Option<Int>,
pub transaction_id: Option<OwnedTransactionId>,
pub prev_content: Option<C>,
pub relations: Option<Relations>,
}events only.Expand description
Extra information about a state event that is not incorporated into the event’s hash.
Fields
age: Option<Int>The time in milliseconds that has elapsed since the event was sent.
This field is generated by the local homeserver, and may be incorrect if the local time on at least one of the two servers is out of sync, which can cause the age to either be negative or greater than it actually is.
transaction_id: Option<OwnedTransactionId>The client-supplied transaction ID, if the client being given the event is the same one which sent it.
prev_content: Option<C>Optional previous content of the event.
relations: Option<Relations>unstable-msc2675 only.Server-compiled information from other events relating to this event.
Implementations
sourceimpl<C: StateEventContent> StateUnsigned<C>
impl<C: StateEventContent> StateUnsigned<C>
sourcepub fn is_empty(&self) -> bool
pub fn is_empty(&self) -> bool
Whether this unsigned data is empty (all fields are None).
This method is used to determine whether to skip serializing the unsigned field in room
events. Do not use it to determine whether an incoming unsigned field was present - it
could still have been present but contained none of the known fields.