[][src]Module ruma_common::push

Common types for the push notifications module

Structs

AnyPushRule

Like PushRule, but may represent any kind of push rule thanks to pattern and conditions being optional.

ConditionalPushRule

Like PushRule, but with an additional conditions field.

ConditionalPushRuleInit

Initial set of fields of ConditionalPushRule.

MissingConditionsError

An error that happens when AnyPushRule cannot be converted into ConditionalPushRule

MissingPatternError

An error that happens when AnyPushRule cannot be converted into PatternedPushRule

PatternedPushRule

Like PushRule, but with an additional pattern field.

PatternedPushRuleInit

Initial set of fields of PatterenedPushRule.

PushRule

A push rule is a single rule that states under what conditions an event should be passed onto a push gateway and how the notification should be presented.

PushRuleInit

Initial set of fields of PushRule.

RoomMemberCountIs

A decimal integer optionally prefixed by one of ==, <, >, >= or <=.

Ruleset

A push ruleset scopes a set of rules according to some criteria.

Enums

Action

This represents the different actions that should be taken when a rule is matched, and controls how notifications are delivered to the client.

ComparisonOperator

One of ==, <, >, >= or <=.

PushCondition

A condition that must apply for an associated push rule's action to be taken.

Tweak

The set_tweak action.