Enum ruma_common::push::Action
source · pub enum Action {
Notify,
DontNotify,
Coalesce,
SetTweak(Tweak),
// some variants omitted
}Expand description
This represents the different actions that should be taken when a rule is matched, and controls how notifications are delivered to the client.
See the spec for details.
Variants
Notify
Causes matching events to generate a notification.
DontNotify
Prevents matching events from generating a notification.
Coalesce
Behaves like notify but homeservers may choose to coalesce multiple events into a single notification.
SetTweak(Tweak)
Sets an entry in the ‘tweaks’ dictionary sent to the push gateway.