Enum ruma_common::push::AnyPushRule
source · pub enum AnyPushRule {
Override(ConditionalPushRule),
Content(PatternedPushRule),
Room(SimplePushRule<OwnedRoomId>),
Sender(SimplePushRule<OwnedUserId>),
Underride(ConditionalPushRule),
}Expand description
The kinds of push rules that are available.
Variants
Override(ConditionalPushRule)
Rules that override all other kinds.
Content(PatternedPushRule)
Content-specific rules.
Room(SimplePushRule<OwnedRoomId>)
Room-specific rules.
Sender(SimplePushRule<OwnedUserId>)
Sender-specific rules.
Underride(ConditionalPushRule)
Lowest priority rules.
Implementations
sourceimpl AnyPushRule
impl AnyPushRule
sourcepub fn as_ref(&self) -> AnyPushRuleRef<'_>
pub fn as_ref(&self) -> AnyPushRuleRef<'_>
Convert AnyPushRule to AnyPushRuleRef.
sourcepub fn applies(
&self,
event: &FlattenedJson,
context: &PushConditionRoomCtx
) -> bool
pub fn applies(
&self,
event: &FlattenedJson,
context: &PushConditionRoomCtx
) -> bool
Check if the push rule applies to the event.
Arguments
event- The flattened JSON representation of a room message event.context- The context of the room at the time of the event.