pub enum AnyPushRuleRef<'a> {
    Override(&'a ConditionalPushRule),
    Content(&'a PatternedPushRule),
    Room(&'a SimplePushRule<OwnedRoomId>),
    Sender(&'a SimplePushRule<OwnedUserId>),
    Underride(&'a ConditionalPushRule),
}
Reference to any kind of push rule.

Variants



Override(&'a ConditionalPushRule)

Rules that override all other kinds.



Content(&'a PatternedPushRule)

Content-specific rules.



Room(&'a SimplePushRule<OwnedRoomId>)

Room-specific rules.



Sender(&'a SimplePushRule<OwnedUserId>)

Sender-specific rules.



Underride(&'a ConditionalPushRule)

Lowest priority rules.

Implementations

source

impl<'a> AnyPushRuleRef<'a>

source

pub fn to_owned(self) -> AnyPushRule

Convert AnyPushRuleRef to AnyPushRule by cloning the inner value.

source

pub fn enabled(self) -> bool

Get the enabled flag of the push rule.

source

pub fn actions(self) -> &'a [Action]

Get the actions of the push rule.

source

pub fn rule_id(self) -> &'a str

Get the rule_id of the push rule.

source

pub fn applies(
    self,
    event: &FlattenedJson,
    context: &PushConditionRoomCtx
) -> bool

Check if the push rule applies to the event.

Arguments
  • event - The flattened JSON representation of a room message event.
  • context - The context of the room at the time of the event.