Enum ruma_common::push::InsertPushRuleError
source · #[non_exhaustive]
pub enum InsertPushRuleError {
ServerDefaultRuleId,
InvalidRuleId,
RelativeToServerDefaultRule,
UnknownRuleId,
BeforeHigherThanAfter,
}Expand description
The error type returned when trying to insert a user-defined push rule into a Ruleset.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
ServerDefaultRuleId
The rule ID starts with a dot (.), which is reserved for server-default rules.
InvalidRuleId
The rule ID contains an invalid character.
RelativeToServerDefaultRule
The rule is being placed relative to a server-default rule, which is forbidden.
UnknownRuleId
The before or after rule could not be found.
BeforeHigherThanAfter
before has a higher priority than after.