#[non_exhaustive]
pub enum PredefinedOverrideRuleId {
Master,
SuppressNotices,
InviteForMe,
MemberEvent,
ContainsDisplayName,
Tombstone,
RoomServerAcl,
RoomNotif,
Reaction,
// some variants omitted
}Expand description
The rule IDs of the predefined override server push rules.
This type can hold an arbitrary string. To build this with a custom value, convert it from a
string with ::from() / .into(). To check for values that are not available as a
documented variant here, use its string representation, obtained through
.as_str().
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Master
.m.rule.master
SuppressNotices
.m.rule.suppress_notices
InviteForMe
.m.rule.invite_for_me
MemberEvent
.m.rule.member_event
ContainsDisplayName
.m.rule.contains_display_name
Tombstone
.m.rule.tombstone
RoomServerAcl
.m.rule.room.server_acl
RoomNotif
.m.rule.roomnotif
Reaction
Available on crate feature
unstable-msc2677 only..m.rule.reaction
Implementations