Struct ruma_common::push::HttpPusherData
source · pub struct HttpPusherData {
pub url: String,
pub format: Option<PushFormat>,
pub default_payload: JsonValue,
}Expand description
Information for a pusher using the Push Gateway API.
Fields
url: StringThe URL to use to send notifications to.
Required if the pusher’s kind is http.
format: Option<PushFormat>The format to use when sending notifications to the Push Gateway.
default_payload: JsonValueAvailable on crate feature
unstable-unspecified only.iOS (+ macOS?) specific default payload that will be sent to apple push notification service.
For more information, see Sygnal docs.
Implementations