Struct ruma_common::push::NewConditionalPushRule
source · pub struct NewConditionalPushRule {
pub rule_id: String,
pub conditions: Vec<PushCondition>,
pub actions: Vec<Action>,
}Expand description
A conditional push rule to update or create.
Fields
rule_id: StringThe ID of this rule.
conditions: Vec<PushCondition>The conditions that must hold true for an event in order for a rule to be applied to an event.
A rule with no conditions always matches.
actions: Vec<Action>Actions to determine if and how a notification is delivered for events matching this rule.
Implementations