[][src]Struct ruma_common::push::OverridePushRule

pub struct OverridePushRule(pub ConditionalPushRule);

Wrapper type to disambiguate the kind of the wrapped rule

Implementations

impl OverridePushRule[src]

Default override push rules

pub fn master() -> Self[src]

Matches all events, this can be enabled to turn off all push notifications other than those generated by override rules set by the user.

pub fn suppress_notices() -> Self[src]

Matches messages with a msgtype of notice.

pub fn invite_for_me(user_id: &UserId) -> Self[src]

Matches any invites to a new room for this user.

pub fn member_event() -> Self[src]

Matches any m.room.member_event.

pub fn contains_display_name() -> Self[src]

Matches any message whose content is unencrypted and contains the user's current display name in the room in which it was sent.

pub fn tombstone() -> Self[src]

Matches any state event whose type is m.room.tombstone. This is intended to notify users of a room when it is upgraded, similar to what an @room notification would accomplish.

pub fn roomnotif() -> Self[src]

Matches any message whose content is unencrypted and contains the text @room, signifying the whole room should be notified of the event.