pub struct SimplePushRule<T> {
    pub actions: Vec<Action>,
    pub default: bool,
    pub enabled: bool,
    pub rule_id: T,
}
A push rule is a single rule that states under what conditions an event should be passed onto a push gateway and how the notification should be presented.

These rules are stored on the user’s homeserver. They are manually configured by the user, who can create and view them via the Client/Server API.

To create an instance of this type, first create a SimplePushRuleInit and convert it via SimplePushRule::from / .into().

Fields

actions: Vec<Action>

Actions to determine if and how a notification is delivered for events matching this rule.

default: bool

Whether this is a default rule, or has been set explicitly.

enabled: bool

Whether the push rule is enabled or not.

rule_id: T

The ID of this rule.

This is generally the Matrix ID of the entity that it applies to.