Enum ruma_common::receipt::ReceiptType [−][src]
#[non_exhaustive]
pub enum ReceiptType {
Read,
// some variants omitted
}Expand description
The type of receipt.
This type can hold an arbitrary string. To check for formats that are not available as a
documented variant here, use its string representation, obtained through .as_str().
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
m.read
Implementations