Struct ruma_common::MilliSecondsSinceUnixEpoch [−][src]
pub struct MilliSecondsSinceUnixEpoch(pub UInt);
A timestamp represented as the number of milliseconds since the unix epoch.
Tuple Fields
0: UIntImplementations
Creates a new MilliSecondsSinceUnixEpoch from the given SystemTime, if it is not before
the unix epoch, or too large to be represented.
Creates a new SystemTime from self, if it can be represented.