Struct ruma_common::SecondsSinceUnixEpoch [−][src]
pub struct SecondsSinceUnixEpoch(pub UInt);
A timestamp represented as the number of seconds since the unix epoch.
Implementations
Creates a new MilliSecondsSinceUnixEpoch from the given SystemTime, if it is not before
the unix epoch, or too large to be represented.
Creates a new SystemTime from self, if it can be represented.