Struct ruma_common::Signatures

source ·
pub struct Signatures<E: Ord, K: ?Sized>(_);
Map of all signatures, grouped by entity

let key_identifier = KeyId::from_parts(SigningKeyAlgorithm::Ed25519, "1");
let mut signatures = Signatures::new();
let server_name = server_name!("example.org");
let signature =
    "YbJva03ihSj5mPk+CHMJKUKlCXCPFXjXOK6VqBnN9nA2evksQcTGn6hwQfrgRHIDDXO2le49x7jnWJHMJrJoBQ";
signatures.insert(server_name, key_identifier, signature.into());

Implementations

source

impl<E: Ord, K: ?Sized> Signatures<E, K>

source

pub fn new() -> Self

Creates an empty signature map.

source

pub fn insert(
    &mut self,
    entity: E,
    key_identifier: OwnedSigningKeyId<K>,
    value: String
) -> Option<String>

Add a signature for the given server name and key identifier.

If there was already one, it is returned.

source

pub fn get<Q>(&self, entity: &Q) -> Option<&EntitySignatures<K>>where
    E: Borrow<Q>,
    Q: Ord + ?Sized,

Returns a reference to the signatures corresponding to the entities.