Struct ruma_common::thirdparty::FieldTypeInit
source · pub struct FieldTypeInit {
pub regexp: String,
pub placeholder: String,
}Expand description
Initial set of fields of FieldType.
This struct will not be updated even if additional fields are added to FieldType in a new
(non-breaking) release of the Matrix specification.
Fields
regexp: StringA regular expression for validation of a field’s value.
placeholder: StringA placeholder serving as a valid example of the field value.