Struct ruma_common::thirdparty::Location [−][src]
#[non_exhaustive]pub struct Location { pub alias: RoomAliasId, pub protocol: String, pub fields: BTreeMap<String, String>, }
A third party network location.
Fields (Non-exhaustive)
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct {{ .. }} syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.alias: RoomAliasIdAn alias for a matrix room.
protocol: StringThe protocol ID that the third party location is a part of.
fields: BTreeMap<String, String>Information used to identify this third party location.
Implementations
impl Location[src]
pub fn new(
alias: RoomAliasId,
protocol: String,
fields: BTreeMap<String, String>
) -> Self[src]
alias: RoomAliasId,
protocol: String,
fields: BTreeMap<String, String>
) -> Self
Creates a new Location with the given alias, protocol and fields.