Struct ruma_common::thirdparty::ProtocolInstance
source · pub struct ProtocolInstance {
pub desc: String,
pub icon: Option<String>,
pub fields: BTreeMap<String, String>,
pub network_id: String,
pub instance_id: String,
}Expand description
Metadata about an instance of a third party protocol.
To create an instance of this type, first create a ProtocolInstanceInit and convert it via
ProtocolInstance::from / .into().
Fields
desc: StringA human-readable description for the protocol, such as the name.
icon: Option<String>An optional content URI representing the protocol.
fields: BTreeMap<String, String>Preset values for fields the client may use to search by.
network_id: StringA unique identifier across all instances.
instance_id: StringAvailable on crate feature
unstable-unspecified only.A unique identifier across all instances.
See matrix-spec#833.