Struct ruma_common::thirdparty::ThirdPartyIdentifier
source · pub struct ThirdPartyIdentifier {
pub address: String,
pub medium: Medium,
pub validated_at: MilliSecondsSinceUnixEpoch,
pub added_at: MilliSecondsSinceUnixEpoch,
}Expand description
An identifier external to Matrix.
To create an instance of this type, first create a ThirdPartyIdentifierInit and convert it to
this type using ThirdPartyIdentifier::Init / .into().
Fields
address: StringThe third party identifier address.
medium: MediumThe medium of third party identifier.
validated_at: MilliSecondsSinceUnixEpochThe time when the identifier was validated by the identity server.
added_at: MilliSecondsSinceUnixEpochThe time when the homeserver associated the third party identifier with the user.