Struct ruma_common::thirdparty::ThirdPartyIdentifierInit
source · pub struct ThirdPartyIdentifierInit {
pub address: String,
pub medium: Medium,
pub validated_at: MilliSecondsSinceUnixEpoch,
pub added_at: MilliSecondsSinceUnixEpoch,
}Expand description
Initial set of fields of ThirdPartyIdentifier.
This struct will not be updated even if additional fields are added to ThirdPartyIdentifier
in a new (non-breaking) release of the Matrix specification.
Fields
address: StringThe third party identifier address.
medium: MediumThe medium of third party identifier.
validated_at: MilliSecondsSinceUnixEpochThe time when the identifier was validated by the identity server.
added_at: MilliSecondsSinceUnixEpochThe time when the homeserver associated the third party identifier with the user.