Struct ruma_common::thirdparty::User [−][src]
A third party network user.
Fields
userid: UserIdA matrix user ID representing a third party user.
protocol: StringThe protocol ID that the third party user is a part of.
fields: BTreeMap<String, String>Information used to identify this third party user.
Implementations
impl User[src]
pub fn new(
userid: UserId,
protocol: String,
fields: BTreeMap<String, String>
) -> Self[src]
userid: UserId,
protocol: String,
fields: BTreeMap<String, String>
) -> Self
Creates a new User with the given userid, protocol and fields.