Type Definition ruma_common::ServerSignatures
source · pub type ServerSignatures = Signatures<OwnedServerName, OwnedKeyName>;Expand description
Map of server signatures for an event, grouped by server.
pub type ServerSignatures = Signatures<OwnedServerName, OwnedKeyName>;Map of server signatures for an event, grouped by server.