Enum ruma_common::api::SendAccessToken
source · [−]Available on crate feature
api only.Expand description
An enum to control whether an access token should be added to outgoing requests
Variants
IfRequired(&'a str)
Add the given access token to the request only if the METADATA on the request requires
it.
Always(&'a str)
Always add the access token.
None
Don’t add an access token.
This will lead to an error if the request endpoint requires authentication
Implementations
sourceimpl<'a> SendAccessToken<'a>
impl<'a> SendAccessToken<'a>
sourcepub fn get_required_for_endpoint(self) -> Option<&'a str>
pub fn get_required_for_endpoint(self) -> Option<&'a str>
Get the access token for an endpoint that requires one.
Returns Some(_) if self contains an access token.
sourcepub fn get_not_required_for_endpoint(self) -> Option<&'a str>
pub fn get_not_required_for_endpoint(self) -> Option<&'a str>
Get the access token for an endpoint that should not require one.
Returns Some(_) only if self is SendAccessToken::Always(_).