Struct ruma_common::directory::PublicRoomsChunkInit [−][src]
pub struct PublicRoomsChunkInit {
pub num_joined_members: UInt,
pub room_id: RoomId,
pub world_readable: bool,
pub guest_can_join: bool,
}Initial set of mandatory fields of PublicRoomsChunk.
This struct will not be updated even if additional fields are added to PublicRoomsChunk in a
new (non-breaking) release of the Matrix specification.
Fields
num_joined_members: UIntThe number of members joined to the room.
room_id: RoomIdThe ID of the room.
world_readable: boolWhether the room may be viewed by guest users without joining.
guest_can_join: boolWhether guest users may join the room and participate in it.
If they can, they will be subject to ordinary power level rules like any other user.