Struct ruma_common::encryption::DeviceKeys[][src]

#[non_exhaustive]
pub struct DeviceKeys { pub user_id: UserId, pub device_id: DeviceIdBox, pub algorithms: Vec<EventEncryptionAlgorithm>, pub keys: BTreeMap<DeviceKeyId, String>, pub signatures: BTreeMap<UserId, BTreeMap<DeviceKeyId, String>>, pub unsigned: UnsignedDeviceInfo, }

Identity keys for a device.

Fields (Non-exhaustive)

Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct {{ .. }} syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
user_id: UserId

The ID of the user the device belongs to. Must match the user ID used when logging in.

device_id: DeviceIdBox

The ID of the device these keys belong to. Must match the device ID used when logging in.

algorithms: Vec<EventEncryptionAlgorithm>

The encryption algorithms supported by this device.

keys: BTreeMap<DeviceKeyId, String>

Public identity keys.

signatures: BTreeMap<UserId, BTreeMap<DeviceKeyId, String>>

Signatures for the device key object.

unsigned: UnsignedDeviceInfo

Additional data added to the device key information by intermediate servers, and not covered by the signatures.

Implementations

impl DeviceKeys[src]

pub fn new(
    user_id: UserId,
    device_id: DeviceIdBox,
    algorithms: Vec<EventEncryptionAlgorithm>,
    keys: BTreeMap<DeviceKeyId, String>,
    signatures: BTreeMap<UserId, BTreeMap<DeviceKeyId, String>>
) -> Self
[src]

Creates a new DeviceKeys from the given user id, device id, algorithms, keys and signatures.