Struct ruma_common::encryption::UnsignedDeviceInfo[][src]

#[non_exhaustive]
pub struct UnsignedDeviceInfo { pub device_display_name: Option<String>, }

Additional data added to device key information by intermediate servers.

Fields (Non-exhaustive)

Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct {{ .. }} syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
device_display_name: Option<String>

The display name which the user set on the device.

Implementations

impl UnsignedDeviceInfo[src]

pub fn new() -> Self[src]

Creates an empty UnsignedDeviceInfo.

pub fn is_empty(&self) -> bool[src]

Checks whether all fields are empty / None.