Struct ruma_common::events::audio::Waveform
source · pub struct Waveform(_);Available on crate features
events and unstable-msc3246 only.Expand description
The waveform representation of audio content.
Must include between 30 and 120 Amplitudes.
To build this, use the TryFrom implementations.
Implementations
sourceimpl Waveform
impl Waveform
sourcepub const MIN_LENGTH: usize = 30usize
pub const MIN_LENGTH: usize = 30usize
The smallest number of values contained in a Waveform.
sourcepub const MAX_LENGTH: usize = 120usize
pub const MAX_LENGTH: usize = 120usize
The largest number of values contained in a Waveform.
sourcepub fn amplitudes(&self) -> &[Amplitude]
pub fn amplitudes(&self) -> &[Amplitude]
The amplitudes of this Waveform.