Struct ruma_common::events::call::select_answer::CallSelectAnswerEventContent
source · [−]pub struct CallSelectAnswerEventContent {
pub call_id: OwnedVoipId,
pub party_id: OwnedVoipId,
pub selected_party_id: OwnedVoipId,
pub version: VoipVersionId,
}Available on crate features
events and unstable-msc2746 only.Expand description
Added in VoIP version 1. The content of an m.call.select_answer event.
This event is sent by the caller when it has chosen an answer.
Fields
call_id: OwnedVoipIdThe ID of the call this event relates to.
party_id: OwnedVoipIdA unique ID for this session for the duration of the call.
Must be the same as the one sent by the previous invite from this session.
selected_party_id: OwnedVoipIdThe party ID of the selected answer to the previously sent invite.
version: VoipVersionIdThe version of the VoIP specification this messages adheres to.
Cannot be older than VoipVersionId::V1.
Implementations
sourceimpl CallSelectAnswerEventContent
impl CallSelectAnswerEventContent
sourcepub fn new(
call_id: OwnedVoipId,
party_id: OwnedVoipId,
selected_party_id: OwnedVoipId,
version: VoipVersionId
) -> Self
pub fn new(
call_id: OwnedVoipId,
party_id: OwnedVoipId,
selected_party_id: OwnedVoipId,
version: VoipVersionId
) -> Self
Creates a CallSelectAnswerEventContent with the given call ID, VoIP version, party ID and
selected party ID.
sourcepub fn version_1(
call_id: OwnedVoipId,
party_id: OwnedVoipId,
selected_party_id: OwnedVoipId
) -> Self
pub fn version_1(
call_id: OwnedVoipId,
party_id: OwnedVoipId,
selected_party_id: OwnedVoipId
) -> Self
Convenience method to create a version 1 CallSelectAnswerEventContent with all the
required fields.