pub enum AnySyncMessageLikeEvent {
Show 26 variants
Audio(SyncAudioEvent),
CallAnswer(SyncCallAnswerEvent),
CallInvite(SyncCallInviteEvent),
CallHangup(SyncCallHangupEvent),
CallCandidates(SyncCallCandidatesEvent),
Emote(SyncEmoteEvent),
File(SyncFileEvent),
Image(SyncImageEvent),
KeyVerificationReady(SyncKeyVerificationReadyEvent),
KeyVerificationStart(SyncKeyVerificationStartEvent),
KeyVerificationCancel(SyncKeyVerificationCancelEvent),
KeyVerificationAccept(SyncKeyVerificationAcceptEvent),
KeyVerificationKey(SyncKeyVerificationKeyEvent),
KeyVerificationMac(SyncKeyVerificationMacEvent),
KeyVerificationDone(SyncKeyVerificationDoneEvent),
Location(SyncLocationEvent),
Message(SyncMessageEvent),
Notice(SyncNoticeEvent),
Reaction(SyncReactionEvent),
RoomEncrypted(SyncRoomEncryptedEvent),
RoomMessage(SyncRoomMessageEvent),
RoomMessageFeedback(SyncRoomMessageFeedbackEvent),
RoomRedaction(SyncRoomRedactionEvent),
Sticker(SyncStickerEvent),
Video(SyncVideoEvent),
Voice(SyncVoiceEvent),
// some variants omitted
}events only.Expand description
Any message-like event.
Variants
Audio(SyncAudioEvent)
unstable-msc3246 only.m.audio
CallAnswer(SyncCallAnswerEvent)
m.call.answer
CallInvite(SyncCallInviteEvent)
m.call.invite
CallHangup(SyncCallHangupEvent)
m.call.hangup
CallCandidates(SyncCallCandidatesEvent)
m.call.candidates
Emote(SyncEmoteEvent)
unstable-msc1767 only.m.emote
File(SyncFileEvent)
unstable-msc3551 only.m.file
Image(SyncImageEvent)
unstable-msc3552 only.m.image
KeyVerificationReady(SyncKeyVerificationReadyEvent)
m.key.verification.ready
KeyVerificationStart(SyncKeyVerificationStartEvent)
m.key.verification.start
KeyVerificationCancel(SyncKeyVerificationCancelEvent)
m.key.verification.cancel
KeyVerificationAccept(SyncKeyVerificationAcceptEvent)
m.key.verification.accept
KeyVerificationKey(SyncKeyVerificationKeyEvent)
m.key.verification.key
KeyVerificationMac(SyncKeyVerificationMacEvent)
m.key.verification.mac
KeyVerificationDone(SyncKeyVerificationDoneEvent)
m.key.verification.done
Location(SyncLocationEvent)
unstable-msc3488 only.m.location
Message(SyncMessageEvent)
unstable-msc1767 only.m.message
Notice(SyncNoticeEvent)
unstable-msc1767 only.m.notice
Reaction(SyncReactionEvent)
unstable-msc2677 only.m.reaction
RoomEncrypted(SyncRoomEncryptedEvent)
m.room.encrypted
RoomMessage(SyncRoomMessageEvent)
m.room.message
RoomMessageFeedback(SyncRoomMessageFeedbackEvent)
m.room.message.feedback
RoomRedaction(SyncRoomRedactionEvent)
m.room.redaction
Sticker(SyncStickerEvent)
m.sticker
Video(SyncVideoEvent)
unstable-msc3553 only.m.video
Voice(SyncVoiceEvent)
unstable-msc3245 only.m.voice
Implementations
sourceimpl AnySyncMessageLikeEvent
impl AnySyncMessageLikeEvent
sourcepub fn event_type(&self) -> MessageLikeEventType
pub fn event_type(&self) -> MessageLikeEventType
Returns the type of this event.
sourcepub fn original_content(&self) -> Option<AnyMessageLikeEventContent>
pub fn original_content(&self) -> Option<AnyMessageLikeEventContent>
Returns the content for this event if it is not redacted, or None if it is.
sourcepub fn origin_server_ts(&self) -> MilliSecondsSinceUnixEpoch
pub fn origin_server_ts(&self) -> MilliSecondsSinceUnixEpoch
Returns this event’s origin_server_ts field.
sourcepub fn transaction_id(&self) -> Option<&TransactionId>
pub fn transaction_id(&self) -> Option<&TransactionId>
Returns this event’s transaction_id from inside unsigned, if there is one.
sourceimpl AnySyncMessageLikeEvent
impl AnySyncMessageLikeEvent
sourcepub fn into_full_event(self, room_id: OwnedRoomId) -> AnyMessageLikeEvent
pub fn into_full_event(self, room_id: OwnedRoomId) -> AnyMessageLikeEvent
Convert this sync event into a full event (one with a room_id field).