Enum ruma_common::events::EventType
source · [−]pub enum EventType {
Show 65 variants
Direct,
IdentityServer,
IgnoredUserList,
PushRules,
SecretStorageDefaultKey,
SecretStorageKey(String),
FullyRead,
Tag,
Receipt,
Typing,
Audio,
CallAnswer,
CallInvite,
CallHangup,
CallCandidates,
Emote,
File,
Image,
KeyVerificationReady,
KeyVerificationStart,
KeyVerificationCancel,
KeyVerificationAccept,
KeyVerificationKey,
KeyVerificationMac,
KeyVerificationDone,
Location,
Message,
Notice,
Reaction,
RoomEncrypted,
RoomMessage,
RoomMessageFeedback,
RoomRedaction,
Sticker,
Video,
Voice,
PolicyRuleRoom,
PolicyRuleServer,
PolicyRuleUser,
RoomAliases,
RoomAvatar,
RoomCanonicalAlias,
RoomCreate,
RoomEncryption,
RoomGuestAccess,
RoomHistoryVisibility,
RoomJoinRules,
RoomMember,
RoomName,
RoomPinnedEvents,
RoomPowerLevels,
RoomServerAcl,
RoomThirdPartyInvite,
RoomTombstone,
RoomTopic,
SpaceChild,
SpaceParent,
Dummy,
RoomKey,
RoomKeyRequest,
ForwardedRoomKey,
KeyVerificationRequest,
SecretRequest,
SecretSend,
Presence,
// some variants omitted
}use a fine-grained event type enum like RoomEventType instead
events only.Expand description
The type of Event this is.
This type can hold an arbitrary string. To build events with a custom type, convert it
from a string with ::from() / .into(). To check for events that are not available as a
documented variant here, use its string representation, obtained through .to_string().
Variants
Direct
use a fine-grained event type enum like RoomEventType instead
m.direct
IdentityServer
use a fine-grained event type enum like RoomEventType instead
m.identity_server
IgnoredUserList
use a fine-grained event type enum like RoomEventType instead
m.ignored_user_list
PushRules
use a fine-grained event type enum like RoomEventType instead
m.push_rules
SecretStorageDefaultKey
use a fine-grained event type enum like RoomEventType instead
m.secret_storage.default_key
SecretStorageKey(String)
use a fine-grained event type enum like RoomEventType instead
m.secret_storage.key.*
FullyRead
use a fine-grained event type enum like RoomEventType instead
m.fully_read
Tag
use a fine-grained event type enum like RoomEventType instead
m.tag
Receipt
use a fine-grained event type enum like RoomEventType instead
m.receipt
Typing
use a fine-grained event type enum like RoomEventType instead
m.typing
Audio
use a fine-grained event type enum like RoomEventType instead
unstable-msc3246 only.m.audio
CallAnswer
use a fine-grained event type enum like RoomEventType instead
m.call.answer
CallInvite
use a fine-grained event type enum like RoomEventType instead
m.call.invite
CallHangup
use a fine-grained event type enum like RoomEventType instead
m.call.hangup
CallCandidates
use a fine-grained event type enum like RoomEventType instead
m.call.candidates
Emote
use a fine-grained event type enum like RoomEventType instead
unstable-msc1767 only.m.emote
File
use a fine-grained event type enum like RoomEventType instead
unstable-msc3551 only.m.file
Image
use a fine-grained event type enum like RoomEventType instead
unstable-msc3552 only.m.image
KeyVerificationReady
use a fine-grained event type enum like RoomEventType instead
m.key.verification.ready
KeyVerificationStart
use a fine-grained event type enum like RoomEventType instead
m.key.verification.start
KeyVerificationCancel
use a fine-grained event type enum like RoomEventType instead
m.key.verification.cancel
KeyVerificationAccept
use a fine-grained event type enum like RoomEventType instead
m.key.verification.accept
KeyVerificationKey
use a fine-grained event type enum like RoomEventType instead
m.key.verification.key
KeyVerificationMac
use a fine-grained event type enum like RoomEventType instead
m.key.verification.mac
KeyVerificationDone
use a fine-grained event type enum like RoomEventType instead
m.key.verification.done
Location
use a fine-grained event type enum like RoomEventType instead
unstable-msc3488 only.m.location
Message
use a fine-grained event type enum like RoomEventType instead
unstable-msc1767 only.m.message
Notice
use a fine-grained event type enum like RoomEventType instead
unstable-msc1767 only.m.notice
Reaction
use a fine-grained event type enum like RoomEventType instead
unstable-msc2677 only.m.reaction
RoomEncrypted
use a fine-grained event type enum like RoomEventType instead
m.room.encrypted
RoomMessage
use a fine-grained event type enum like RoomEventType instead
m.room.message
RoomMessageFeedback
use a fine-grained event type enum like RoomEventType instead
m.room.message.feedback
RoomRedaction
use a fine-grained event type enum like RoomEventType instead
m.room.redaction
Sticker
use a fine-grained event type enum like RoomEventType instead
m.sticker
Video
use a fine-grained event type enum like RoomEventType instead
unstable-msc3553 only.m.video
Voice
use a fine-grained event type enum like RoomEventType instead
unstable-msc3245 only.m.voice
PolicyRuleRoom
use a fine-grained event type enum like RoomEventType instead
m.policy.rule.room
PolicyRuleServer
use a fine-grained event type enum like RoomEventType instead
m.policy.rule.server
PolicyRuleUser
use a fine-grained event type enum like RoomEventType instead
m.policy.rule.user
RoomAliases
use a fine-grained event type enum like RoomEventType instead
m.room.aliases
RoomAvatar
use a fine-grained event type enum like RoomEventType instead
m.room.avatar
RoomCanonicalAlias
use a fine-grained event type enum like RoomEventType instead
m.room.canonical_alias
RoomCreate
use a fine-grained event type enum like RoomEventType instead
m.room.create
RoomEncryption
use a fine-grained event type enum like RoomEventType instead
m.room.encryption
RoomGuestAccess
use a fine-grained event type enum like RoomEventType instead
m.room.guest_access
RoomHistoryVisibility
use a fine-grained event type enum like RoomEventType instead
m.room.history_visibility
RoomJoinRules
use a fine-grained event type enum like RoomEventType instead
m.room.join_rules
RoomMember
use a fine-grained event type enum like RoomEventType instead
m.room.member
RoomName
use a fine-grained event type enum like RoomEventType instead
m.room.name
RoomPinnedEvents
use a fine-grained event type enum like RoomEventType instead
m.room.pinned_events
RoomPowerLevels
use a fine-grained event type enum like RoomEventType instead
m.room.power_levels
RoomServerAcl
use a fine-grained event type enum like RoomEventType instead
m.room.server_acl
RoomThirdPartyInvite
use a fine-grained event type enum like RoomEventType instead
m.room.third_party_invite
RoomTombstone
use a fine-grained event type enum like RoomEventType instead
m.room.tombstone
RoomTopic
use a fine-grained event type enum like RoomEventType instead
m.room.topic
SpaceChild
use a fine-grained event type enum like RoomEventType instead
m.space.child
SpaceParent
use a fine-grained event type enum like RoomEventType instead
m.space.parent
Dummy
use a fine-grained event type enum like RoomEventType instead
m.dummy
RoomKey
use a fine-grained event type enum like RoomEventType instead
m.room_key
RoomKeyRequest
use a fine-grained event type enum like RoomEventType instead
m.room_key_request
ForwardedRoomKey
use a fine-grained event type enum like RoomEventType instead
m.forwarded_room_key
KeyVerificationRequest
use a fine-grained event type enum like RoomEventType instead
m.key.verification.request
SecretRequest
use a fine-grained event type enum like RoomEventType instead
m.secret.request
SecretSend
use a fine-grained event type enum like RoomEventType instead
m.secret.send
Presence
use a fine-grained event type enum like RoomEventType instead
m.presence