Available on crate feature
events only.Expand description
The content of an m.identity_server event.
Persists the user’s preferred identity server, or preference to not use an identity server at all.
Fields
base_url: JsOption<String>The URL of the identity server the user prefers to use, or Null if the user does not want
to use an identity server.
If this is Undefined, that means the user has not expressed a preference or has revoked
their preference, and any applicable default should be used.