Struct ruma_common::events::room::EncryptedFile
source · [−]pub struct EncryptedFile {
pub url: OwnedMxcUri,
pub key: JsonWebKey,
pub iv: Base64,
pub hashes: BTreeMap<String, Base64>,
pub v: String,
}Available on crate feature
events only.Expand description
A file sent to a room with end-to-end encryption enabled.
To create an instance of this type, first create a EncryptedFileInit and convert it via
EncryptedFile::from / .into().
Fields
url: OwnedMxcUriThe URL to the file.
key: JsonWebKeyA JSON Web Key object.
iv: Base64The 128-bit unique counter block used by AES-CTR, encoded as unpadded base64.
hashes: BTreeMap<String, Base64>A map from an algorithm name to a hash of the ciphertext, encoded as unpadded base64.
Clients should support the SHA-256 hash, which uses the key sha256.
v: StringVersion of the encrypted attachments protocol.
Must be v2.