logo
pub struct RequestedKeyInfo {
    pub algorithm: EventEncryptionAlgorithm,
    pub room_id: OwnedRoomId,
    pub sender_key: String,
    pub session_id: String,
}
Available on crate feature events only.
Information about a requested key.

Fields

algorithm: EventEncryptionAlgorithm

The encryption algorithm the requested key in this event is to be used with.

room_id: OwnedRoomId

The room where the key is used.

sender_key: String
👎Deprecated:

this field still needs to be sent but should not be used when received

The Curve25519 key of the device which initiated the session originally.

session_id: String

The ID of the session that the key is for.

Implementations

Creates a new RequestedKeyInfo with the given algorithm, room ID, sender key and session ID.