Struct ruma_common::events::sticker::StickerEventContent
source · pub struct StickerEventContent {
pub body: String,
pub info: ImageInfo,
pub url: OwnedMxcUri,
pub message: Option<MessageContent>,
pub file: Option<FileContent>,
pub image: Option<Box<ImageContent>>,
pub thumbnail: Option<Vec<ThumbnailContent>>,
pub caption: Option<MessageContent>,
}events only.Expand description
The content of an m.sticker event.
A sticker message.
With the unstable-msc3552 feature, this type also contains the transitional extensible events
format. See the documentation of the message module for more information.
Fields
body: StringA textual representation or associated description of the sticker image.
This could be the alt text of the original image, or a message to accompany and further describe the sticker.
info: ImageInfoMetadata about the image referred to in url including a thumbnail representation.
url: OwnedMxcUriThe URL to the sticker image.
message: Option<MessageContent>unstable-msc3552 only.Extensible-event text representation of the message.
If present, this should be preferred over the body field.
file: Option<FileContent>unstable-msc3552 only.Extensible-event file content of the message.
If present, this should be preferred over the url, file and info fields.
image: Option<Box<ImageContent>>unstable-msc3552 only.Extensible-event image info of the message.
If present, this should be preferred over the info field.
thumbnail: Option<Vec<ThumbnailContent>>unstable-msc3552 only.Extensible-event thumbnails of the message.
If present, this should be preferred over the info field.
caption: Option<MessageContent>unstable-msc3552 only.Extensible-event captions of the message.
Implementations
sourceimpl StickerEventContent
impl StickerEventContent
sourcepub fn new(body: String, info: ImageInfo, url: OwnedMxcUri) -> Self
pub fn new(body: String, info: ImageInfo, url: OwnedMxcUri) -> Self
Creates a new StickerEventContent with the given body, image info and URL.