Struct ruma_common::events::InitialStateEvent
source · pub struct InitialStateEvent<C: StaticStateEventContent> {
pub content: C,
pub state_key: C::StateKey,
}Available on crate feature
events only.Expand description
A minimal state event, used for creating a new room.
Fields
content: CData specific to the event type.
state_key: C::StateKeyA unique key which defines the overwriting semantics for this piece of room state.
This is often an empty string, but some events send a UserId to show which user the event
affects.
Defaults to the empty string.