[−][src]Module ruma_common::push
Common types for the push notifications module
Structs
| AnyPushRule | Like |
| ConditionalPushRule | Like |
| ConditionalPushRuleInit | Initial set of fields of |
| MissingConditionsError | An error that happens when |
| MissingPatternError | An error that happens when |
| PatternedPushRule | Like |
| PatternedPushRuleInit | Initial set of fields of |
| PushRule | A push rule is a single rule that states under what conditions an event should be passed onto a push gateway and how the notification should be presented. |
| PushRuleInit | Initial set of fields of |
| RoomMemberCountIs | A decimal integer optionally prefixed by one of |
| Ruleset | A push ruleset scopes a set of rules according to some criteria. |
Enums
| Action | This represents the different actions that should be taken when a rule is matched, and controls how notifications are delivered to the client. |
| ComparisonOperator | One of |
| PushCondition | A condition that must apply for an associated push rule's action to be taken. |
| Tweak | The |