[−][src]Module ruma_common::push
Common types for the push notifications module
Enums
| Action | This represents the different actions that should be taken when a rule is matched, and controls how notifications are delivered to the client. |
| Tweak | The |