Enum ruma_common::push::Action[][src]

#[non_exhaustive]
pub enum Action {
    Notify,
    DontNotify,
    Coalesce,
    SetTweak(Tweak),
}
This represents the different actions that should be taken when a rule is matched, and controls how notifications are delivered to the client.

See https://matrix.org/docs/spec/client_server/r0.6.0#actions for details.

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Notify
Causes matching events to generate a notification.

DontNotify
Prevents matching events from generating a notification.

Coalesce
Behaves like notify but homeservers may choose to coalesce multiple events into a single notification.

SetTweak(Tweak)
Sets an entry in the ‘tweaks’ dictionary sent to the push gateway.