Enum ruma_common::push::Action [−][src]
#[non_exhaustive]
pub enum Action {
Notify,
DontNotify,
Coalesce,
SetTweak(Tweak),
}Expand description
This represents the different actions that should be taken when a rule is matched, and controls how notifications are delivered to the client.
See https://matrix.org/docs/spec/client_server/r0.6.0#actions for details.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Causes matching events to generate a notification.
Prevents matching events from generating a notification.
Behaves like notify but homeservers may choose to coalesce multiple events into a single notification.
SetTweak(Tweak)Expand description
Sets an entry in the ‘tweaks’ dictionary sent to the push gateway.