Enum ruma_common::push::AnyPushRule [−][src]
pub enum AnyPushRule {
Override(ConditionalPushRule),
Content(PatternedPushRule),
Room(SimplePushRule),
Sender(SimplePushRule),
Underride(ConditionalPushRule),
}Expand description
The kinds of push rules that are available.
Variants
Rules that override all other kinds.
Tuple Fields of Override
Content-specific rules.
Tuple Fields of Content
Room-specific rules.
Tuple Fields of Room
Sender-specific rules.
Tuple Fields of Sender
Lowest priority rules.
Tuple Fields of Underride
Implementations
Convert AnyPushRule to AnyPushRuleRef.
Check if the push rule applies to the event.
Arguments
event- The flattened JSON representation of a room message event.context- The context of the room at the time of the event.