Enum ruma_common::push::AnyPushRule [−][src]
pub enum AnyPushRule {
Override(ConditionalPushRule),
Content(PatternedPushRule),
Room(SimplePushRule),
Sender(SimplePushRule),
Underride(ConditionalPushRule),
}Expand description
The kinds of push rules that are available.
Variants
Override(ConditionalPushRule)Rules that override all other kinds.
Content(PatternedPushRule)Content-specific rules.
Room(SimplePushRule)Room-specific rules.
Sender(SimplePushRule)Sender-specific rules.
Underride(ConditionalPushRule)Lowest priority rules.
Implementations
Convert AnyPushRule to AnyPushRuleRef.
Check if the push rule applies to the event.
Arguments
event- The flattened JSON representation of a room message event.context- The context of the room at the time of the event.