Enum ruma_common::push::AnyPushRule [−][src]
pub enum AnyPushRule {
Override(ConditionalPushRule),
Content(PatternedPushRule),
Room(SimplePushRule),
Sender(SimplePushRule),
Underride(ConditionalPushRule),
}Expand description
The kinds of push rules that are available.
Variants
Override(ConditionalPushRule)Expand description
Rules that override all other kinds.
Content(PatternedPushRule)Expand description
Content-specific rules.
Room(SimplePushRule)Expand description
Room-specific rules.
Sender(SimplePushRule)Expand description
Sender-specific rules.
Underride(ConditionalPushRule)Expand description
Lowest priority rules.
Implementations
impl AnyPushRule[src]
impl AnyPushRule[src]pub fn as_ref(&self) -> AnyPushRuleRef<'_>[src]
pub fn as_ref(&self) -> AnyPushRuleRef<'_>[src]Convert AnyPushRule to AnyPushRuleRef.
pub fn applies(
&self,
event: &FlattenedJson,
context: &PushConditionRoomCtx
) -> bool[src]
pub fn applies(
&self,
event: &FlattenedJson,
context: &PushConditionRoomCtx
) -> bool[src]Check if the push rule applies to the event.
Arguments
event- The flattened JSON representation of a room message event.context- The context of the room at the time of the event.