Enum ruma_common::push::AnyPushRule [−][src]
pub enum AnyPushRule {
Override(ConditionalPushRule),
Content(PatternedPushRule),
Room(SimplePushRule),
Sender(SimplePushRule),
Underride(ConditionalPushRule),
}The kinds of push rules that are available.
Variants
Override(ConditionalPushRule)Rules that override all other kinds.
Content(PatternedPushRule)Content-specific rules.
Room(SimplePushRule)Room-specific rules.
Sender(SimplePushRule)Sender-specific rules.
Underride(ConditionalPushRule)Lowest priority rules.
Implementations
impl AnyPushRule[src]
pub fn as_ref(&self) -> AnyPushRuleRef<'_>[src]
Convert AnyPushRule to AnyPushRuleRef.
pub fn enabled(&self) -> bool[src]
Get the enabled flag of the push rule.
pub fn actions(&self) -> &[Action][src]
Get the actions of the push rule.
pub fn rule_id(&self) -> &str[src]
Get the rule_id of the push rule.
pub fn applies(
&self,
event: &FlattenedJson,
context: &PushConditionRoomCtx
) -> bool[src]
&self,
event: &FlattenedJson,
context: &PushConditionRoomCtx
) -> bool
Check if the push rule applies to the event.
Arguments
event- The flattened JSON representation of a room message event.context- The context of the room at the time of the event.