Enum ruma_common::push::AnyPushRuleRef [−][src]
pub enum AnyPushRuleRef<'a> {
Override(&'a ConditionalPushRule),
Content(&'a PatternedPushRule),
Room(&'a SimplePushRule),
Sender(&'a SimplePushRule),
Underride(&'a ConditionalPushRule),
}Expand description
Reference to any kind of push rule.
Variants
Override(&'a ConditionalPushRule)Rules that override all other kinds.
Content(&'a PatternedPushRule)Content-specific rules.
Room(&'a SimplePushRule)Room-specific rules.
Sender(&'a SimplePushRule)Sender-specific rules.
Underride(&'a ConditionalPushRule)Lowest priority rules.
Implementations
Convert AnyPushRuleRef to AnyPushRule by cloning the inner value.
Check if the push rule applies to the event.
Arguments
event- The flattened JSON representation of a room message event.context- The context of the room at the time of the event.