Enum ruma_common::push::AnyPushRuleRef[][src]

pub enum AnyPushRuleRef<'a> {
    Override(&'a ConditionalPushRule),
    Content(&'a PatternedPushRule),
    Room(&'a SimplePushRule),
    Sender(&'a SimplePushRule),
    Underride(&'a ConditionalPushRule),
}
Reference to any kind of push rule.

Variants

Override(&'a ConditionalPushRule)

Rules that override all other kinds.

Content(&'a PatternedPushRule)

Content-specific rules.

Room(&'a SimplePushRule)

Room-specific rules.

Sender(&'a SimplePushRule)

Sender-specific rules.

Underride(&'a ConditionalPushRule)

Lowest priority rules.

Implementations

impl<'a> AnyPushRuleRef<'a>[src]

pub fn to_owned(self) -> AnyPushRule[src]

Convert AnyPushRuleRef to AnyPushRule by cloning the inner value.

pub fn enabled(self) -> bool[src]

Get the enabled flag of the push rule.

pub fn actions(self) -> &'a [Action][src]

Get the actions of the push rule.

pub fn rule_id(self) -> &'a str[src]

Get the rule_id of the push rule.

pub fn applies(
    self,
    event: &FlattenedJson,
    context: &PushConditionRoomCtx
) -> bool
[src]

Check if the push rule applies to the event.

Arguments

  • event - The flattened JSON representation of a room message event.
  • context - The context of the room at the time of the event.