Enum ruma_common::push::AnyPushRuleRef [−][src]
pub enum AnyPushRuleRef<'a> {
Override(&'a ConditionalPushRule),
Content(&'a PatternedPushRule),
Room(&'a SimplePushRule),
Sender(&'a SimplePushRule),
Underride(&'a ConditionalPushRule),
}Expand description
Reference to any kind of push rule.
Variants
Override(&'a ConditionalPushRule)Expand description
Rules that override all other kinds.
Content(&'a PatternedPushRule)Expand description
Content-specific rules.
Room(&'a SimplePushRule)Expand description
Room-specific rules.
Sender(&'a SimplePushRule)Expand description
Sender-specific rules.
Underride(&'a ConditionalPushRule)Expand description
Lowest priority rules.
Implementations
impl<'a> AnyPushRuleRef<'a>[src]
impl<'a> AnyPushRuleRef<'a>[src]pub fn to_owned(self) -> AnyPushRule[src]
pub fn to_owned(self) -> AnyPushRule[src]Convert AnyPushRuleRef to AnyPushRule by cloning the inner value.
pub fn applies(
self,
event: &FlattenedJson,
context: &PushConditionRoomCtx
) -> bool[src]
pub fn applies(
self,
event: &FlattenedJson,
context: &PushConditionRoomCtx
) -> bool[src]Check if the push rule applies to the event.
Arguments
event- The flattened JSON representation of a room message event.context- The context of the room at the time of the event.