Enum ruma_common::push::PushCondition [−][src]
pub enum PushCondition {
EventMatch {
key: String,
pattern: String,
},
ContainsDisplayName,
RoomMemberCount {
is: RoomMemberCountIs,
},
SenderNotificationPermission {
key: String,
},
}Expand description
A condition that must apply for an associated push rule’s action to be taken.
Variants
This is a glob pattern match on a field of the event.
Show fields
This matches unencrypted messages where content.body contains the owner’s display name in
that room.
This matches the current number of members in the room.
Show fields
Fields of RoomMemberCount
is: RoomMemberCountIsThe condition on the current number of members in the room.
This takes into account the current power levels in the room, ensuring the sender of the event has high enough power to trigger the notification.
Show fields
Fields of SenderNotificationPermission
key: StringThe field in the power level event the user needs a minimum power level for.
Fields must be specified under the notifications property in the power level event’s
content.
Implementations
Check if this condition applies to the event.
Arguments
event- The flattened JSON representation of a room message event.context- The context of the room at the time of the event.