Enum ruma_common::push::PushCondition[][src]

#[non_exhaustive]
pub enum PushCondition {
    EventMatch {
        key: String,
        pattern: String,
    },
    ContainsDisplayName,
    RoomMemberCount {
        is: RoomMemberCountIs,
    },
    SenderNotificationPermission {
        key: String,
    },
}
A condition that must apply for an associated push rule’s action to be taken.

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
EventMatch
This is a glob pattern match on a field of the event.

Show fields

Fields of EventMatch

key: String
The dot-separated field of the event to match.

pattern: String
The glob-style pattern to match against.

Patterns with no special glob characters should be treated as having asterisks prepended and appended when testing the condition.

ContainsDisplayName
This matches unencrypted messages where content.body contains the owner’s display name in that room.

RoomMemberCount
This matches the current number of members in the room.

Show fields

Fields of RoomMemberCount

is: RoomMemberCountIs
The condition on the current number of members in the room.

SenderNotificationPermission
This takes into account the current power levels in the room, ensuring the sender of the event has high enough power to trigger the notification.

Show fields

Fields of SenderNotificationPermission

key: String
The field in the power level event the user needs a minimum power level for.

Fields must be specified under the notifications property in the power level event’s content.

Implementations

impl PushCondition[src]

pub fn applies(
    &self,
    event: &FlattenedJson,
    context: &PushConditionRoomCtx
) -> bool
[src]

Check if this condition applies to the event.

Arguments

  • event - The flattened JSON representation of a room message event.
  • context - The context of the room at the time of the event.