Enum ruma_common::push::PushFormat [−][src]
pub enum PushFormat {
EventIdOnly,
// some variants omitted
}Expand description
A special format that the homeserver should use when sending notifications to a Push Gateway. Currently, only “event_id_only” is supported as of Push Gateway API r0.1.1.
Variants
Require the homeserver to only send a reduced set of fields in the push.