Enum ruma_common::push::Tweak [−][src]
#[non_exhaustive]
pub enum Tweak {
Sound(String),
Highlight(bool),
Custom {
name: String,
value: Box<RawJsonValue>,
},
}Expand description
The set_tweak action.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Sound(String)Expand description
A string representing the sound to be played when this notification arrives.
A value of “default” means to play a default sound. A device may choose to alert the user by some other means if appropriate, eg. vibration.
Highlight(bool)Expand description
A boolean representing whether or not this message should be highlighted in the UI.
This will normally take the form of presenting the message in a different color and/or
style. The UI might also be adjusted to draw particular attention to the room in which the
event occurred. If a highlight tweak is given with no value, its value is defined to be
true. If no highlight tweak is given at all then the value of highlight is defined to
be false.
A custom tweak
Show fields
Fields of Custom
name: StringExpand description
The name of the custom tweak (set_tweak field)
value: Box<RawJsonValue>Expand description
The value of the custom tweak