Struct ruma_common::push::ConditionalPushRule [−][src]
#[non_exhaustive]pub struct ConditionalPushRule { pub actions: Vec<Action>, pub default: bool, pub enabled: bool, pub rule_id: String, pub conditions: Vec<PushCondition>, }
Like SimplePushRule, but with an additional conditions field.
Only applicable to underride and override rules.
To create an instance of this type, first create a ConditionalPushRuleInit and convert it via
ConditionalPushRule::from / .into().
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct {{ .. }} syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.actions: Vec<Action>Expand description
Actions to determine if and how a notification is delivered for events matching this rule.
default: boolExpand description
Whether this is a default rule, or has been set explicitly.
enabled: boolExpand description
Whether the push rule is enabled or not.
rule_id: StringExpand description
The ID of this rule.
conditions: Vec<PushCondition>Expand description
The conditions that must hold true for an event in order for a rule to be applied to an event.
A rule with no conditions always matches.
Implementations
impl ConditionalPushRule[src]
impl ConditionalPushRule[src]Default override push rules
pub fn master() -> Self[src]
pub fn master() -> Self[src]Matches all events, this can be enabled to turn off all push notifications other than those generated by override rules set by the user.
pub fn suppress_notices() -> Self[src]
pub fn suppress_notices() -> Self[src]Matches messages with a msgtype of notice.
pub fn invite_for_me(user_id: &UserId) -> Self[src]
pub fn invite_for_me(user_id: &UserId) -> Self[src]Matches any invites to a new room for this user.
pub fn member_event() -> Self[src]
pub fn member_event() -> Self[src]Matches any m.room.member_event.
pub fn contains_display_name() -> Self[src]
pub fn contains_display_name() -> Self[src]Matches any message whose content is unencrypted and contains the user’s current display name in the room in which it was sent.
impl ConditionalPushRule[src]
impl ConditionalPushRule[src]Default underrides push rules
pub fn encrypted_room_one_to_one() -> Self[src]
pub fn encrypted_room_one_to_one() -> Self[src]Matches any encrypted event sent in a room with exactly two members. Unlike other push rules, this rule cannot be matched against the content of the event by nature of it being encrypted. This causes the rule to be an “all or nothing” match where it either matches all events that are encrypted (in 1:1 rooms) or none.
pub fn room_one_to_one() -> Self[src]
pub fn room_one_to_one() -> Self[src]Matches any message sent in a room with exactly two members.
pub fn encrypted() -> Self[src]
pub fn encrypted() -> Self[src]Matches all encrypted events. Unlike other push rules, this rule cannot be matched against the content of the event by nature of it being encrypted. This causes the rule to be an “all or nothing” match where it either matches all events that are encrypted (in group rooms) or none.
impl ConditionalPushRule[src]
impl ConditionalPushRule[src]pub fn applies(
&self,
event: &FlattenedJson,
context: &PushConditionRoomCtx
) -> bool[src]
pub fn applies(
&self,
event: &FlattenedJson,
context: &PushConditionRoomCtx
) -> bool[src]Check if the push rule applies to the event.
Arguments
event- The flattened JSON representation of a room message event.context- The context of the room at the time of the event.