[−][src]Struct ruma_common::push::ConditionalPushRule
Like PushRule, but with an additional conditions field.
Only applicable to underride and override rules.
To create an instance of this type, first create a ConditionalPushRuleInit and convert it via
ConditionalPushRule::from / .into().
Fields (Non-exhaustive)
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.actions: Vec<Action>Actions to determine if and how a notification is delivered for events matching this rule.
default: boolWhether this is a default rule, or has been set explicitly.
enabled: boolWhether the push rule is enabled or not.
rule_id: StringThe ID of this rule.
conditions: Vec<PushCondition>The conditions that must hold true for an event in order for a rule to be applied to an event.
A rule with no conditions always matches.