Struct ruma_common::push::ConditionalPushRuleInit [−][src]
pub struct ConditionalPushRuleInit {
pub actions: Vec<Action>,
pub default: bool,
pub enabled: bool,
pub rule_id: String,
pub conditions: Vec<PushCondition>,
}Expand description
Initial set of fields of ConditionalPushRule.
This struct will not be updated even if additional fields are added to ConditionalPushRule in
a new (non-breaking) release of the Matrix specification.
Fields
actions: Vec<Action>Expand description
Actions to determine if and how a notification is delivered for events matching this rule.
default: boolExpand description
Whether this is a default rule, or has been set explicitly.
enabled: boolExpand description
Whether the push rule is enabled or not.
rule_id: StringExpand description
The ID of this rule.
conditions: Vec<PushCondition>Expand description
The conditions that must hold true for an event in order for a rule to be applied to an event.
A rule with no conditions always matches.