Struct ruma_common::push::ConditionalPushRuleInit [−][src]
pub struct ConditionalPushRuleInit {
pub actions: Vec<Action>,
pub default: bool,
pub enabled: bool,
pub rule_id: String,
pub conditions: Vec<PushCondition>,
}Initial set of fields of ConditionalPushRule.
This struct will not be updated even if additional fields are added to ConditionalPushRule in
a new (non-breaking) release of the Matrix specification.
Fields
actions: Vec<Action>Actions to determine if and how a notification is delivered for events matching this rule.
default: boolWhether this is a default rule, or has been set explicitly.
enabled: boolWhether the push rule is enabled or not.
rule_id: StringThe ID of this rule.
conditions: Vec<PushCondition>The conditions that must hold true for an event in order for a rule to be applied to an event.
A rule with no conditions always matches.