[−][src]Struct ruma_common::push::ContentPushRule
Wrapper type to disambiguate the kind of the wrapped rule
Implementations
impl ContentPushRule[src]
Default content push rules
pub fn contains_user_name(user_id: &UserId) -> Self[src]
Matches any message whose content is unencrypted and contains the local part of the user's Matrix ID, separated by word boundaries.