Struct ruma_common::push::PatternedPushRule
source · pub struct PatternedPushRule {
pub actions: Vec<Action>,
pub default: bool,
pub enabled: bool,
pub rule_id: String,
pub pattern: String,
}Expand description
Like SimplePushRule, but with an additional pattern field.
Only applicable to content rules.
To create an instance of this type, first create a PatternedPushRuleInit and convert it via
PatternedPushRule::from / .into().
Fields
actions: Vec<Action>Actions to determine if and how a notification is delivered for events matching this rule.
default: boolWhether this is a default rule, or has been set explicitly.
enabled: boolWhether the push rule is enabled or not.
rule_id: StringThe ID of this rule.
pattern: StringThe glob-style pattern to match against.
Implementations
sourceimpl PatternedPushRule
impl PatternedPushRule
Default content push rules
sourcepub fn contains_user_name(user_id: &UserId) -> Self
pub fn contains_user_name(user_id: &UserId) -> Self
Matches any message whose content is unencrypted and contains the local part of the user’s Matrix ID, separated by word boundaries.
sourceimpl PatternedPushRule
impl PatternedPushRule
sourcepub fn applies_to(
&self,
key: &str,
event: &FlattenedJson,
context: &PushConditionRoomCtx
) -> bool
pub fn applies_to(
&self,
key: &str,
event: &FlattenedJson,
context: &PushConditionRoomCtx
) -> bool
Check if the push rule applies to the event.
Arguments
event- The flattened JSON representation of a room message event.context- The context of the room at the time of the event.