Struct ruma_common::push::PatternedPushRule [−][src]
#[non_exhaustive]pub struct PatternedPushRule { pub actions: Vec<Action>, pub default: bool, pub enabled: bool, pub rule_id: String, pub pattern: String, }
Like SimplePushRule, but with an additional pattern field.
Only applicable to content rules.
To create an instance of this type, first create a PatternedPushRuleInit and convert it via
PatternedPushRule::from / .into().
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct {{ .. }} syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.actions: Vec<Action>Expand description
Actions to determine if and how a notification is delivered for events matching this rule.
default: boolExpand description
Whether this is a default rule, or has been set explicitly.
enabled: boolExpand description
Whether the push rule is enabled or not.
rule_id: StringExpand description
The ID of this rule.
pattern: StringExpand description
The glob-style pattern to match against.
Implementations
impl PatternedPushRule[src]
impl PatternedPushRule[src]Default content push rules
pub fn contains_user_name(user_id: &UserId) -> Self[src]
pub fn contains_user_name(user_id: &UserId) -> Self[src]Matches any message whose content is unencrypted and contains the local part of the user’s Matrix ID, separated by word boundaries.
impl PatternedPushRule[src]
impl PatternedPushRule[src]pub fn applies_to(
&self,
key: &str,
event: &FlattenedJson,
context: &PushConditionRoomCtx
) -> bool[src]
pub fn applies_to(
&self,
key: &str,
event: &FlattenedJson,
context: &PushConditionRoomCtx
) -> bool[src]Check if the push rule applies to the event.
Arguments
event- The flattened JSON representation of a room message event.context- The context of the room at the time of the event.