Struct ruma_common::push::PushConditionRoomCtx
source · pub struct PushConditionRoomCtx {
pub room_id: OwnedRoomId,
pub member_count: UInt,
pub user_id: OwnedUserId,
pub user_display_name: String,
pub users_power_levels: BTreeMap<OwnedUserId, Int>,
pub default_power_level: Int,
pub notification_power_levels: NotificationPowerLevels,
pub supported_features: Vec<RoomVersionFeature>,
}Expand description
The context of the room associated to an event to be able to test all push conditions.
Fields
room_id: OwnedRoomIdThe ID of the room.
member_count: UIntThe number of members in the room.
user_id: OwnedUserIdThe users matrix ID.
user_display_name: StringThe display name of the current user in the room.
users_power_levels: BTreeMap<OwnedUserId, Int>The power levels of the users of the room.
default_power_level: IntThe default power level of the users of the room.
notification_power_levels: NotificationPowerLevelsThe notification power levels of the room.
supported_features: Vec<RoomVersionFeature>Available on crate feature
unstable-msc3931 only.The list of features this room’s version or the room itself supports.