Struct ruma_common::push::PushConditionRoomCtx [−][src]
pub struct PushConditionRoomCtx {
pub room_id: RoomId,
pub member_count: UInt,
pub user_display_name: String,
pub users_power_levels: BTreeMap<UserId, Int>,
pub default_power_level: Int,
pub notification_power_levels: NotificationPowerLevels,
}The context of the room associated to an event to be able to test all push conditions.
Fields
room_id: RoomIdThe ID of the room.
member_count: UIntThe number of members in the room.
user_display_name: StringThe display name of the current user in the room.
users_power_levels: BTreeMap<UserId, Int>The power levels of the users of the room.
default_power_level: IntThe default power level of the users of the room.
notification_power_levels: NotificationPowerLevelsThe notification power levels of the room.