Struct ruma_common::push::RoomMemberCountIs[][src]

pub struct RoomMemberCountIs {
    pub prefix: ComparisonOperator,
    pub count: UInt,
}
A decimal integer optionally prefixed by one of ==, <, >, >= or <=.

A prefix of < matches rooms where the member count is strictly less than the given number and so forth. If no prefix is present, this parameter defaults to ==.

Can be constructed from a number or a range:

use js_int::uint;
use ruma_common::push::RoomMemberCountIs;

// equivalent to `is: "3"` or `is: "==3"`
let exact = RoomMemberCountIs::from(uint!(3));

// equivalent to `is: ">=3"`
let greater_or_equal = RoomMemberCountIs::from(uint!(3)..);

// equivalent to `is: "<3"`
let less = RoomMemberCountIs::from(..uint!(3));

// equivalent to `is: "<=3"`
let less_or_equal = RoomMemberCountIs::from(..=uint!(3));

// An exclusive range can be constructed with `RoomMemberCountIs::gt`:
// (equivalent to `is: ">3"`)
let greater = RoomMemberCountIs::gt(uint!(3));

Fields

prefix: ComparisonOperator
One of ==, <, >, >=, <=, or no prefix.

count: UInt
The number of people in the room.

Implementations

impl RoomMemberCountIs[src]

pub fn gt(count: UInt) -> Self[src]

Creates an instance of RoomMemberCount equivalent to <X, where X is the specified member count.