[−][src]Struct ruma_common::push::Ruleset
A push ruleset scopes a set of rules according to some criteria.
For example, some rules may only be applied for messages from a particular sender, a particular room, or by default. The push ruleset contains the entire set of scopes and rules.
Fields (Non-exhaustive)
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.content: BTreeSet<ContentPushRule>These rules configure behavior for (unencrypted) messages that match certain patterns.
override_: BTreeSet<OverridePushRule>These user-configured rules are given the highest priority.
This field is named override_ instead of override because the latter is a reserved
keyword in Rust.
room: BTreeSet<RoomPushRule>These rules change the behavior of all messages for a given room.
sender: BTreeSet<SenderPushRule>These rules configure notification behavior for messages from a specific Matrix user ID.
underride: BTreeSet<UnderridePushRule>These rules are identical to override rules, but have a lower priority than content,
room and sender rules.
Implementations
impl Ruleset[src]
pub fn server_default(user_id: &UserId) -> Self[src]
The list of all predefined push rules.
Parameters
user_id: the user for which to generate the default rules. Some rules depend on the user's ID (for instance those to send notifications when they are mentioned).
impl Ruleset[src]
pub fn new() -> Self[src]
Creates an empty Ruleset.
pub fn add<R: RulesetMember>(&mut self, rule: R) -> bool[src]
Adds a rule to the rule set.
Returns true if the new rule was correctly added, and false
if a rule with the same rule_id is already present for this kind
of rule.