Struct ruma_common::push::SimplePushRule [−][src]
#[non_exhaustive]pub struct SimplePushRule { pub actions: Vec<Action>, pub default: bool, pub enabled: bool, pub rule_id: String, }
A push rule is a single rule that states under what conditions an event should be passed onto a push gateway and how the notification should be presented.
These rules are stored on the user’s homeserver. They are manually configured by the user, who can create and view them via the Client/Server API.
To create an instance of this type, first create a SimplePushRuleInit and convert it via
SimplePushRule::from / .into().
Fields (Non-exhaustive)
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct {{ .. }} syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.actions: Vec<Action>Actions to determine if and how a notification is delivered for events matching this rule.
default: boolWhether this is a default rule, or has been set explicitly.
enabled: boolWhether the push rule is enabled or not.
rule_id: StringThe ID of this rule.