Struct ruma_common::push::SimplePushRuleInit [−][src]
pub struct SimplePushRuleInit {
pub actions: Vec<Action>,
pub default: bool,
pub enabled: bool,
pub rule_id: String,
}Expand description
Initial set of fields of SimplePushRule.
This struct will not be updated even if additional fields are added to SimplePushRule in a new
(non-breaking) release of the Matrix specification.
Fields
actions: Vec<Action>Expand description
Actions to determine if and how a notification is delivered for events matching this rule.
default: boolExpand description
Whether this is a default rule, or has been set explicitly.
enabled: boolExpand description
Whether the push rule is enabled or not.
rule_id: StringExpand description
The ID of this rule.