[−][src]Struct ruma_common::push::UnderridePushRule
Wrapper type to disambiguate the kind of the wrapped rule
Implementations
impl UnderridePushRule[src]
Default underrides push rules
pub fn call() -> Self[src]
Matches any incoming VOIP call.
pub fn encrypted_room_one_to_one() -> Self[src]
Matches any encrypted event sent in a room with exactly two members. Unlike other push rules, this rule cannot be matched against the content of the event by nature of it being encrypted. This causes the rule to be an "all or nothing" match where it either matches all events that are encrypted (in 1:1 rooms) or none.
pub fn room_one_to_one() -> Self[src]
Matches any message sent in a room with exactly two members.
pub fn message() -> Self[src]
Matches all chat messages.
pub fn encrypted() -> Self[src]
Matches all encrypted events. Unlike other push rules, this rule cannot be matched against the content of the event by nature of it being encrypted. This causes the rule to be an "all or nothing" match where it either matches all events that are encrypted (in group rooms) or none.