Struct ruma_common::thirdparty::FieldType
source · [−]Expand description
A type definition for a field used to identify third party users or locations.
To create an instance of this type, first create a FieldTypeInit and convert it via
FieldType::from / .into().
Fields
regexp: StringA regular expression for validation of a field’s value.
placeholder: StringA placeholder serving as a valid example of the field value.