Struct ruma_common::thirdparty::FieldType [−][src]
A type definition for a field used to identify third party users or locations.
To create an instance of this type, first create a FieldTypeInit and convert it via
FieldType::from / .into().
Fields (Non-exhaustive)
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct {{ .. }} syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.regexp: StringA regular expression for validation of a field’s value.
placeholder: StringA placeholder serving as a valid example of the field value.