Struct ruma_common::thirdparty::Protocol [−][src]
#[non_exhaustive]pub struct Protocol { pub user_fields: Vec<String>, pub location_fields: Vec<String>, pub icon: String, pub field_types: BTreeMap<String, FieldType>, pub instances: Vec<ProtocolInstance>, }
Metadata about a third party protocol.
To create an instance of this type, first create a ProtocolInit and convert it via
Protocol::from / .into().
Fields (Non-exhaustive)
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct {{ .. }} syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.user_fields: Vec<String>Fields which may be used to identify a third party user.
location_fields: Vec<String>Fields which may be used to identify a third party location.
icon: StringA content URI representing an icon for the third party protocol.
If you activate the compat feature, this field being absent in JSON will give you an
empty string here.
field_types: BTreeMap<String, FieldType>The type definitions for the fields defined in user_fields and location_fields.
instances: Vec<ProtocolInstance>A list of objects representing independent instances of configuration.