Struct ruma_common::thirdparty::ProtocolInit[][src]

pub struct ProtocolInit {
    pub user_fields: Vec<String>,
    pub location_fields: Vec<String>,
    pub icon: String,
    pub field_types: BTreeMap<String, FieldType>,
    pub instances: Vec<ProtocolInstance>,
}
Initial set of fields of Protocol.

This struct will not be updated even if additional fields are added to Prococol in a new (non-breaking) release of the Matrix specification.

Fields

user_fields: Vec<String>

Fields which may be used to identify a third party user.

location_fields: Vec<String>

Fields which may be used to identify a third party location.

icon: String

A content URI representing an icon for the third party protocol.

field_types: BTreeMap<String, FieldType>

The type definitions for the fields defined in user_fields and location_fields.

instances: Vec<ProtocolInstance>

A list of objects representing independent instances of configuration.