Struct ruma_common::thirdparty::ProtocolInstance [−][src]
#[non_exhaustive]pub struct ProtocolInstance { pub desc: String, pub icon: Option<String>, pub fields: BTreeMap<String, String>, pub network_id: String, }
Metadata about an instance of a third party protocol.
To create an instance of this type, first create a ProtocolInstanceInit and convert it via
ProtocolInstance::from / .into().
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct {{ .. }} syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.desc: StringExpand description
A human-readable description for the protocol, such as the name.
icon: Option<String>Expand description
An optional content URI representing the protocol.
fields: BTreeMap<String, String>Expand description
Preset values for fields the client may use to search by.
network_id: StringExpand description
A unique identifier across all instances.