Struct ruma_common::thirdparty::ProtocolInstanceInit [−][src]
pub struct ProtocolInstanceInit {
pub desc: String,
pub fields: BTreeMap<String, String>,
pub network_id: String,
}Expand description
Initial set of fields of Protocol.
This struct will not be updated even if additional fields are added to Prococol in a new
(non-breaking) release of the Matrix specification.
Fields
desc: StringExpand description
A human-readable description for the protocol, such as the name.
fields: BTreeMap<String, String>Expand description
Preset values for fields the client may use to search by.
network_id: StringExpand description
A unique identifier across all instances.